import * as i0 from '@angular/core';
import { Injectable, Inject, Component, Directive, Input, EventEmitter, Output, NgModule } from '@angular/core';
import * as i7 from '@angular/common';
import { CommonModule } from '@angular/common';
import { pickBy, keys, debounce, isEmpty, mapKeys } from 'lodash';
import { forkJoin, from, of, timer, Observable, throwError } from 'rxjs';
import { map, tap, mergeMap, switchMapTo, repeat, takeWhile, take, last, delay, catchError } from 'rxjs/operators';
import * as i2 from '@angular/material/dialog';
import { MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import { trigger, transition, style, animate, state } from '@angular/animations';
import { ajax } from 'rxjs/ajax';
import { CognitoIdentityClient } from '@aws-sdk/client-cognito-identity';
import { S3Client, PutObjectCommand } from '@aws-sdk/client-s3';
import { fromCognitoIdentityPool } from '@aws-sdk/credential-provider-cognito-identity';
import { StandardRetryStrategy } from '@aws-sdk/middleware-retry';
import { validate, v4 } from 'uuid';
import * as i1 from '@angular/common/http';
import { HttpParams, HttpClientModule } from '@angular/common/http';
import * as i3 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i4 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i5 from '@angular/material/progress-bar';
import { MatProgressBarModule } from '@angular/material/progress-bar';
import * as i6 from '@angular/material/table';
import { MatTableModule } from '@angular/material/table';
import * as i8 from '@angular/material/tooltip';
import { MatTooltipModule } from '@angular/material/tooltip';
import * as React from 'react';
import React__default, { useRef, useEffect, useState, createContext, useCallback, createElement } from 'react';
import { useClassNames, CloseIcon, SandpackStack, DirectoryIconOpen, DirectoryIconClosed, SandpackPreview, SandpackConsole, SandpackProvider } from '@codesandbox/sandpack-react';
import Split from '@uiw/react-split';
import { __rest, __awaiter } from 'tslib';
import Editor, { monaco } from '@codingame/monaco-editor-react';
import { createStitches } from '@stitches/core';
import { getIconForFile, getIconForOpenFolder, getIconForFolder } from 'vscode-material-icon-theme-js';
import '@codingame/monaco-editor-wrapper/features/typescriptContribution';
import '@codingame/monaco-editor-wrapper/features/jsonContribution';
import '@codingame/monaco-editor-wrapper/features/cssContribution';
import '@codingame/monaco-editor-wrapper/features/htmlContribution';
import AsyncSelect from 'react-select/async';
import Tooltip from '@uiw/react-tooltip';
import Mustache from 'mustache';
import Select from 'react-select';
import * as i2$1 from '@angular/material/progress-spinner';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import { createRoot } from 'react-dom/client';

const ifFadeInAnimation = trigger('ifFadeInAnimation', [
    transition(':enter', [
        style({ height: 0, opacity: 0, visibility: 'hidden', overflow: 'hidden' }),
        animate('300ms ease-out', style({ height: '*', opacity: 1, visibility: 'visible' }))
    ]),
    transition(':leave', [
        style({ height: '*', opacity: 1, visibility: 'visible' }),
        animate('300ms ease-in', style({ height: 0, opacity: 0, visibility: 'hidden' }))
    ])
]);
const fadeInAnimation = trigger('fadeInAnimation', [
    state('collapsed, void', style({ height: '0px', visibility: 'hidden', opacity: 0, overflow: 'hidden' })),
    state('expanded', style({ height: '*', visibility: 'visible', opacity: 1 })),
    transition('expanded <=> collapsed, void => collapsed', animate('300ms cubic-bezier(0.4, 0.0, 0.2, 1)')),
]);
const rotateAnimation = trigger('rotateAnimation', [
    state('true', style({ transform: 'rotate(0)' })),
    state('false', style({ transform: 'rotate(180deg)' })),
    transition('true => false', animate('300ms ease-out')),
    transition('false => true', animate('300ms ease-in'))
]);
const rotateAnimation90 = trigger('rotateAnimation90', [
    state('true', style({ transform: 'rotate(0)' })),
    state('false', style({ transform: 'rotate(90deg)' })),
    transition('true => false', animate('300ms ease-out')),
    transition('false => true', animate('300ms ease-in'))
]);

const stringToUUID = (value) => {
    const uuid = value.substr(0, 8) + '-' +
        value.substr(8, 4) + '-' +
        value.substr(12, 4) + '-' +
        value.substr(16, 4) + '-' +
        value.substr(20);
    return uuid;
};
const isValidUUID = (value) => {
    if (validate(value)) {
        return true;
    }
    return validate(stringToUUID(value));
};
class AWS {
    static initialize(environment) {
        this.environment = environment;
        const retryStrategy = new StandardRetryStrategy(() => Promise.resolve(10), { delayDecider: (_delayBase, attempts) => 2 ^ (attempts * 100) });
        retryStrategy.mode = 'STANDARD';
        this.s3Client = new S3Client({
            region: environment.aws_upload.region,
            credentials: fromCognitoIdentityPool({
                client: new CognitoIdentityClient({ region: environment.aws_upload.region }),
                identityPoolId: environment.aws_upload.identityPoolId
            }),
            retryStrategy,
        });
    }
    static uploadFiles(options) {
        const obs = [];
        options.forEach(option => obs.push(this.uploadFile(option)));
        return forkJoin(obs);
    }
    static uploadFile(options) {
        let { file, path, name, unique = true, root = false } = options;
        if (unique) {
            name = `${Date.now()}--${v4()}--${name}`;
        }
        let Key = (`${path}/${name}`).replace(/(null|undefined)+/g, '').split('/').filter(Boolean).join('/');
        if (!isValidUUID(Key.split('/')[0])) {
            Key = `codejudge-s3-cognito/${Key}`;
        }
        const uploadParams = new PutObjectCommand({
            Bucket: this.environment.aws_upload.aws_bucket,
            Key,
            Body: file,
            ACL: this.environment.aws_upload.access_acl,
        });
        return from(this.s3Client.send(uploadParams)).pipe(map(res => ({
            url: `https://${this.environment.aws_upload.aws_bucket}.s3.us-east-1.amazonaws.com/${Key}`,
            fileName: name,
        })));
    }
}

function pollWhile(isPollingActive, emitOnlyLast = false, time, maxAttempts = 10, maxDelay = 10, callback) {
    const dueTime = (typeof time === 'number' ? time : time.dueTime) * 1000;
    const period = (typeof time === 'number' ? time : time.period) * 1000;
    maxDelay = maxDelay * 1000;
    let count = 0;
    return (source$) => {
        const poll$ = of({}).pipe(tap(() => ++count), map(() => count === 1 ? dueTime : Math.min(period * Math.pow(1.5, count), maxDelay)), mergeMap(delay => timer(delay)), switchMapTo(source$), repeat(), takeWhile(isPollingActive, true), take(maxAttempts), tap(res => callback === null || callback === void 0 ? void 0 : callback(res)));
        return emitOnlyLast ? poll$.pipe(last()) : poll$;
    };
}
const resolvablePromise = () => {
    let resolve;
    let reject;
    const promise = new Promise((_resolve, _reject) => {
        resolve = _resolve;
        reject = _reject;
    });
    promise.resolve = resolve;
    promise.reject = reject;
    return promise;
};
function runInZone(zone) {
    return (source) => {
        return new Observable(observer => {
            const onNext = (value) => zone.run(() => observer.next(value));
            const onError = (e) => zone.run(() => observer.error(e));
            const onComplete = () => zone.run(() => observer.complete());
            return source.subscribe(onNext, onError, onComplete);
        });
    };
}

const fetchFromUrl = (urlOrRequest) => {
    return ajax(urlOrRequest).pipe(map(response => response.response));
};

const USER_TYPE = {
    RECRUITER: 'RECRUITER',
    DEVELOPER: 'DEVELOPER',
};
const PORTAL = {
    RECRUITER: 'RECRUITER',
    DEVELOPER: 'DEVELOPER',
    INTERVIEW: 'INTERVIEW',
};
var Constants;
(function (Constants) {
    Constants["TEST"] = "TEST";
    Constants["CONTEST"] = "CONTEST";
})(Constants || (Constants = {}));

class ApiService {
    constructor(http, environment) {
        this.http = http;
        this.environment = environment;
    }
    saveLiveRun(question, uuid, testType, language_id, workspace_url, portal) {
        let body = {
            "test_uuid": uuid,
            "test_type": testType,
            "question_id": question.id,
            "language_id": language_id,
            "question_type": question.type,
            "workspace_url": workspace_url
        };
        if (portal === PORTAL.RECRUITER) {
            body = {
                "id": question.id,
                "optionIds": question.exercises.map(x => x.id),
                "workspaceUrl": workspace_url
            };
            return this.http.post(this.environment.coreApiUrl + 'question-builder/front-end/recruiter/evaluate', body).pipe(map(res => res.response));
        }
        return this.http.post(this.environment.developerApiUrl + '/api/v6/execute-test-cases/async/', body);
    }
    saveSubmission(question, uuid, testType, language_id, workspace_url, portal) {
        let body = {
            "test_uuid": uuid,
            "test_type": testType,
            "question_id": question.id,
            "language_id": language_id,
            "question_type": question.type,
            "project_code_url": workspace_url,
            "single_sub": true
        };
        return this.http.post(this.environment.developerApiUrl + '/api/v1/runs-v3/', body);
    }
    getLiveRunStatus(id, portal, callback) {
        if (portal === PORTAL.RECRUITER) {
            return this.getSubmisssionStatus(id, callback);
        }
        const params = new HttpParams()
            .set('id', id === null || id === void 0 ? void 0 : id.toString());
        return (this.http.get(this.environment.developerApiUrl + '/api/v1/live-run-result/id/', { params })).pipe(map(res => (Object.assign(Object.assign({}, res.response.live_run), { output: this.transformResults(res.response.live_run.output) }))), pollWhile((result) => result.status <= 2, true, 2, 20, undefined, callback), mergeMap(result => this.transformLogs(result)));
    }
    getSubmisssionStatus(id, callback) {
        const params = new HttpParams()
            .set('id', id === null || id === void 0 ? void 0 : id.toString());
        return (this.http.get(this.environment.developerApiUrl + '/api/v1/submission_result/', { params })).pipe(map(res => (Object.assign(Object.assign({}, res.run), { output: this.transformResults(res.run.result_metadata) }))), pollWhile((result) => result.status <= 2, true, 2, 20, undefined, callback), mergeMap(result => this.transformLogs(result)));
    }
    transformResults(results) {
        results = results ? JSON.parse(results) : [];
        results = results.map(exercise => {
            exercise.output = exercise.output ? JSON.parse(exercise.output) : [];
            return exercise;
        });
        return results;
    }
    transformLogs(result) {
        let obs;
        if ((result === null || result === void 0 ? void 0 : result.logs_file) || (result === null || result === void 0 ? void 0 : result.app_logs_file)) {
            obs = fetchFromUrl({ url: (result === null || result === void 0 ? void 0 : result.logs_file) || (result === null || result === void 0 ? void 0 : result.app_logs_file), responseType: 'text' }).pipe(map(logs => (Object.assign(Object.assign({}, result), { logs }))));
        }
        else {
            result.logs = result.application_logs || result.logs || result.app_logs;
            obs = of(result);
        }
        return obs;
    }
}
ApiService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: ApiService, deps: [{ token: i1.HttpClient }, { token: 'environment' }], target: i0.ɵɵFactoryTarget.Injectable });
ApiService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: ApiService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: ApiService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Inject,
                    args: ['environment']
                }] }]; } });
const sample_data1 = {
    "run": {
        "id": 5352,
        "updated_at": "2022-05-11T02:12:08.771532Z",
        "created_at": "2022-05-11T02:12:08.771601Z",
        "user_id": 8,
        "question_id": 1553,
        "git_url": "https://github.com/devjudge/test-1553-q-32a146808a7544ecaa64699f2dc2aabf-8-express4.17.1-in-docker-2.git",
        "code": null,
        "endpoint": null,
        "repo_id": "NODE-10-EXP-4.17.1",
        "commit_id": "e1e1c78aa3750d426339efafd2c2b1ef9b713f6a",
        "branch": "master",
        "env_list": "",
        "run_type": "Server",
        "project_root": "",
        "test_uuid": "32a14680-8a75-44ec-aa64-699f2dc2aabf",
        "status": 4,
        "discrepancy_status": 1,
        "discrepancies": "{\"options\": []}",
        "result_metadata": "[{\"output\": \"\", \"test_case_score\": 20.0, \"status\": \"True\", \"points\": 20.0, \"test_case_id\": 21752, \"testCaseName\": \"Fetch a lead\"}, {\"output\": \"[{\\\"testCaseId\\\": 0, \\\"testCaseName\\\": \\\"Add a new Lead - Test 1\\\", \\\"testCaseResultStatus\\\": \\\"SUCCEEDED\\\", \\\"testCaseExceptionMessage\\\": \\\"\\\", \\\"testResponseCode\\\": 201}, {\\\"testCaseId\\\": 1, \\\"testCaseName\\\": \\\"Add a new Lead - Test 2\\\", \\\"testCaseResultStatus\\\": \\\"SUCCEEDED\\\", \\\"testCaseExceptionMessage\\\": \\\"\\\", \\\"testResponseCode\\\": 400}, {\\\"testCaseId\\\": 2, \\\"testCaseName\\\": \\\"Add a new Lead - Test 3\\\", \\\"testCaseResultStatus\\\": \\\"SUCCEEDED\\\", \\\"testCaseExceptionMessage\\\": \\\"\\\", \\\"testResponseCode\\\": 400}, {\\\"testCaseId\\\": 3, \\\"testCaseName\\\": \\\"Add a new Lead - Test 4\\\", \\\"testCaseResultStatus\\\": \\\"SUCCEEDED\\\", \\\"testCaseExceptionMessage\\\": \\\"\\\", \\\"testResponseCode\\\": 201}, {\\\"testCaseId\\\": 4, \\\"testCaseName\\\": \\\"Check created Lead - Test 1\\\", \\\"testCaseResultStatus\\\": \\\"FAILED\\\", \\\"testCaseExceptionMessage\\\": \\\"Extractor threw exception: Not legal JSON!\\\", \\\"testResponseCode\\\": \\\"Traceback (most recent call last):\\\\n  File \\\\\\\"/usr/local/lib/python3.6/site-packages/pyresttest-1.7.2.dev0-py3.6.egg/pyresttest/validators.py\\\\\\\", line 239, in extract_internal\\\\n    body = json.loads(body)\\\\n  File \\\\\\\"/usr/local/lib/python3.6/json/__init__.py\\\\\\\", line 354, in loads\\\\n    return _default_decoder.decode(s)\\\\n  File \\\\\\\"/usr/local/lib/python3.6/json/decoder.py\\\\\\\", line 339, in decode\\\\n    obj, end = self.raw_decode(s, idx=_w(s, 0).end())\\\\n  File \\\\\\\"/usr/local/lib/python3.6/json/decoder.py\\\\\\\", line 357, in raw_decode\\\\n    raise JSONDecodeError(\\\\\\\"Expecting value\\\\\\\", s, err.value) from None\\\\njson.decoder.JSONDecodeError: Expecting value: line 1 column 1 (char 0)\\\\n\\\\nDuring handling of the above exception, another exception occurred:\\\\n\\\\nTraceback (most recent call last):\\\\n  File \\\\\\\"/usr/local/lib/python3.6/site-packages/pyresttest-1.7.2.dev0-py3.6.egg/pyresttest/validators.py\\\\\\\", line 358, in validate\\\\n    body=body, headers=headers, context=context)\\\\n  File \\\\\\\"/usr/local/lib/python3.6/site-packages/pyresttest-1.7.2.dev0-py3.6.egg/pyresttest/validators.py\\\\\\\", line 185, in extract\\\\n    return self.extract_internal(query=query, body=body, headers=headers, args=self.args)\\\\n  File \\\\\\\"/usr/local/lib/python3.6/site-packages/pyresttest-1.7.2.dev0-py3.6.egg/pyresttest/validators.py\\\\\\\", line 242, in extract_internal\\\\n    raise ValueError(\\\\\\\"Not legal JSON!\\\\\\\")\\\\nValueError: Not legal JSON!\\\\n\\\"}, {\\\"testCaseId\\\": 5, \\\"testCaseName\\\": \\\"Check created Lead - Test 2\\\", \\\"testCaseResultStatus\\\": \\\"FAILED\\\", \\\"testCaseExceptionMessage\\\": \\\"Extractor threw exception: Not legal JSON!\\\", \\\"testResponseCode\\\": \\\"Traceback (most recent call last):\\\\n  File \\\\\\\"/usr/local/lib/python3.6/site-packages/pyresttest-1.7.2.dev0-py3.6.egg/pyresttest/validators.py\\\\\\\", line 239, in extract_internal\\\\n    body = json.loads(body)\\\\n  File \\\\\\\"/usr/local/lib/python3.6/json/__init__.py\\\\\\\", line 354, in loads\\\\n    return _default_decoder.decode(s)\\\\n  File \\\\\\\"/usr/local/lib/python3.6/json/decoder.py\\\\\\\", line 339, in decode\\\\n    obj, end = self.raw_decode(s, idx=_w(s, 0).end())\\\\n  File \\\\\\\"/usr/local/lib/python3.6/json/decoder.py\\\\\\\", line 357, in raw_decode\\\\n    raise JSONDecodeError(\\\\\\\"Expecting value\\\\\\\", s, err.value) from None\\\\njson.decoder.JSONDecodeError: Expecting value: line 1 column 1 (char 0)\\\\n\\\\nDuring handling of the above exception, another exception occurred:\\\\n\\\\nTraceback (most recent call last):\\\\n  File \\\\\\\"/usr/local/lib/python3.6/site-packages/pyresttest-1.7.2.dev0-py3.6.egg/pyresttest/validators.py\\\\\\\", line 358, in validate\\\\n    body=body, headers=headers, context=context)\\\\n  File \\\\\\\"/usr/local/lib/python3.6/site-packages/pyresttest-1.7.2.dev0-py3.6.egg/pyresttest/validators.py\\\\\\\", line 185, in extract\\\\n    return self.extract_internal(query=query, body=body, headers=headers, args=self.args)\\\\n  File \\\\\\\"/usr/local/lib/python3.6/site-packages/pyresttest-1.7.2.dev0-py3.6.egg/pyresttest/validators.py\\\\\\\", line 242, in extract_internal\\\\n    raise ValueError(\\\\\\\"Not legal JSON!\\\\\\\")\\\\nValueError: Not legal JSON!\\\\n\\\"}]\", \"status\": \"False\", \"test_case_score\": 13, \"points\": 20.0, \"test_case_id\": 21753, \"testCaseName\": \"Generate a lead\"}]",
        "score": 33,
        "total_score": 40,
        "quality": 100,
        "logs": "",
        "logs_file": "",
        "application_logs": "",
        "app_logs_file": "https://codejudge-results-dev-dev.s3.amazonaws.com/run-5352-ac52e3ebb083479ea934701c9f1f8fa9-app-logs.txt",
        "passed_tests": 1,
        "language_id": 328,
        "test_type": "TEST",
        "project_zip": "s3://codejudge-results-dev-dev/5352-1553-8.zip",
        "project_zip_v2": "https://codejudge-results-dev-dev.s3.amazonaws.com/5352-1553-8--c92343dce0a64cb798d66c3ef9361fcf.zip",
        "build_zip": null,
        "pdf_uploaded": true,
        "plagiarism_status": null,
        "comparison": "",
        "retry_at": null,
        "retry_count": 0,
        "sonar_retry_at": null,
        "sonar_retry_count": 0,
        "files_changed": 6,
        "insertions": 3926,
        "deletions": 120,
        "version": "V2",
        "zip_uuid": null,
        "language": {
            "id": 328,
            "name": "NODEJS",
            "description": "Questions with NodeJS techonology attribute",
            "displayName": "Nodejs",
            "tagType": {
                "id": 53,
                "name": "TECHNOLOGY_ATTR",
                "displayName": "Technologies",
                "featureType": "ATTRIBUTE"
            },
            "imageUrl": "https://s3.amazonaws.com/codejudge-core/tag/default_bg.jpeg",
            "attributes": "{\"mossLanguage\": \"\", \"fileExtension\": \"\"}"
        }
    },
    "code_quality": {
        "bugs": {
            "total": 0,
            "p": 1,
            "ps": 500,
            "paging": {
                "pageIndex": 1,
                "pageSize": 500,
                "total": 0
            },
            "effortTotal": 0,
            "debtTotal": 0,
            "issues": [],
            "components": [],
            "facets": []
        },
        "codesmells": {
            "total": 0,
            "p": 1,
            "ps": 500,
            "paging": {
                "pageIndex": 1,
                "pageSize": 500,
                "total": 0
            },
            "effortTotal": 0,
            "debtTotal": 0,
            "issues": [],
            "components": [],
            "facets": []
        }
    },
    "metrics": {
        "component": {
            "id": "AYCw75cZ-lmI1iRyonyI",
            "key": "run-5352",
            "name": "run-5352",
            "qualifier": "TRK",
            "measures": {
                "ncloc": "103",
                "reliability_remediation_effort": "0",
                "effort_to_reach_maintainability_rating_a": "0",
                "duplicated_lines_density": "0.0",
                "sqale_index": "0",
                "comment_lines_density": "6.4",
                "blocker_violations": "0",
                "complexity": "15",
                "minor_violations": "0",
                "reopened_issues": "0",
                "false_positive_issues": "0",
                "lines": "159",
                "duplicated_lines": "0",
                "sqale_rating": "1.0",
                "sqale_debt_ratio": "0.0",
                "bugs": "0",
                "vulnerabilities": "0",
                "open_issues": "0",
                "statements": "76",
                "code_smells": "0",
                "classes": "0",
                "violations": "0",
                "critical_violations": "0",
                "reliability_rating": "1.0",
                "duplicated_blocks": "0",
                "duplicated_files": "0",
                "line_coverage": "0.0",
                "file_complexity": "3.0",
                "uncovered_lines": "76",
                "functions": "7",
                "lines_to_cover": "76",
                "confirmed_issues": "0",
                "security_remediation_effort": "0",
                "wont_fix_issues": "0",
                "info_violations": "0",
                "major_violations": "0",
                "security_rating": "1.0",
                "files": "5",
                "comment_lines": "7",
                "cognitive_complexity": "9",
                "alert_status": "OK",
                "coverage": "0.0"
            }
        },
        "code_metrics": [
            {
                "key": "TOTAL_CODESMELLS",
                "name": "Total Codesmells",
                "short_desc": "Indicate weaknesses in design.",
                "desc": "",
                "is_enabled": true,
                "value": 0
            },
            {
                "key": "KEY_CODESMELLS",
                "name": "Critical and Blocker Codesmells",
                "short_desc": "Might have missing edge cases and cause runtime issues.",
                "desc": "",
                "is_enabled": true,
                "value": 0
            },
            {
                "key": "MAINTAINABILITY_RATING",
                "name": "Maintainability Rating(1-5)",
                "short_desc": "Effort to fix code smells. Lower the rating, lesser the effort, better the code quality.",
                "desc": "",
                "is_enabled": true,
                "value": 1.0
            },
            {
                "key": "DUPLICATE_LINE_DENSITY",
                "name": "Duplicate Lines Density(%)",
                "short_desc": "Percentage of duplicate lines with respect to all the lines. Higher the value, lower the code quality",
                "desc": "",
                "is_enabled": true,
                "value": 0.0
            },
            {
                "key": "TOTAL_BUGS",
                "name": "Total Bugs",
                "short_desc": "Indicates code breaking errors that must be fixed immediately.",
                "desc": "",
                "is_enabled": true,
                "value": 0
            },
            {
                "key": "RELIABILITY_RATING",
                "name": "Reliability Rating(1-5)",
                "short_desc": "Based on the worst bug severity. Lower the rating, lesser the bugs, higher the code quality",
                "desc": "",
                "is_enabled": true,
                "value": 1.0
            },
            {
                "key": "COGNITIVE_COMPLEXITY",
                "name": "Cognitive complexity",
                "short_desc": "Indicates code readability. Lesser complexity, better readability, better code quality.",
                "desc": "",
                "is_enabled": true,
                "value": 9
            },
            {
                "key": "CODE_METADATA",
                "name": "Lines of Code & Classes & Functions",
                "short_desc": "Indicates Number of lines of code, classes and functions.",
                "desc": "",
                "is_enabled": true,
                "value": "103 & 0 & 7"
            }
        ]
    }
};
const sample_data2 = {
    "response": {
        "live_run": {
            "id": 2242,
            "updated_at": "2023-09-03T13:19:50.174166Z",
            "created_at": "2023-09-03T13:19:50.174228Z",
            "score": 0,
            "total_score": 60,
            "app_logs": "",
            "logs_file": null,
            "app_logs_file": null,
            "user_id": 1200,
            "ques_id": 3783,
            "option_id": null,
            "test_uuid": "24c18546-70aa-4c52-bcb4-5516cf1d1d2b",
            "test_type": "TEST",
            "code": null,
            "language_id": 395,
            "config": null,
            "status": 3,
            "show_browser": false,
            "type": "Web_V2",
            "output": "[\n    {\n        \"testCaseName\": \"Display final score\",\n        \"output\": \"[]\",\n        \"status\": \"False\",\n        \"points\": 20,\n        \"score\": 0,\n        \"testCaseId\": 64159,\n        \"message\": \"  ● Test suite failed to run\\n\\n    Cannot find module './src/App' from 'src/__tests__/2.test.js'\\n\\n      1 | import React from 'react';\\n      2 | import { render, screen, fireEvent } from '@testing-library/react';\\n    > 3 | import QuizGame from './src/App';\\n        | ^\\n      4 |\\n      5 | test('display correct score 2', () => {\\n      6 |     render(<QuizGame />);\\n\\n      at Resolver.resolveModule (node_modules/jest-runtime/node_modules/jest-resolve/build/index.js:306:11)\\n      at Object.<anonymous> (src/__tests__/2.test.js:3:1)\\n\",\n        \"testCaseExecutionTime\": 0\n    },\n    {\n        \"testCaseName\": \"The restart button is not working\",\n        \"output\": \"[{\\\"testCaseName\\\": \\\"display correct score 2\\\", \\\"testCaseResultStatus\\\": \\\"SUCCEEDED\\\", \\\"testCaseExceptionMessage\\\": \\\"\\\", \\\"testCaseExecutionTime\\\": null}, {\\\"testCaseName\\\": \\\"restart quiz\\\", \\\"testCaseResultStatus\\\": \\\"SUCCEEDED\\\", \\\"testCaseExceptionMessage\\\": \\\"\\\", \\\"testCaseExecutionTime\\\": null}, {\\\"testCaseName\\\": \\\"restart quiz\\\", \\\"testCaseResultStatus\\\": \\\"SUCCEEDED\\\", \\\"testCaseExceptionMessage\\\": \\\"\\\", \\\"testCaseExecutionTime\\\": null}]\",\n        \"status\": \"True\",\n        \"points\": 20,\n        \"score\": 20,\n        \"testCaseId\": 64160,\n        \"message\": null,\n        \"testCaseExecutionTime\": 2219\n    },\n    {\n        \"testCaseName\": \"Increment Score\",\n        \"output\": \"[{\\\"testCaseName\\\": \\\"display correct score 2\\\", \\\"testCaseResultStatus\\\": \\\"SUCCEEDED\\\", \\\"testCaseExceptionMessage\\\": \\\"\\\", \\\"testCaseExecutionTime\\\": null}, {\\\"testCaseName\\\": \\\"restart quiz\\\", \\\"testCaseResultStatus\\\": \\\"SUCCEEDED\\\", \\\"testCaseExceptionMessage\\\": \\\"\\\", \\\"testCaseExecutionTime\\\": null}, {\\\"testCaseName\\\": \\\"restart quiz\\\", \\\"testCaseResultStatus\\\": \\\"SUCCEEDED\\\", \\\"testCaseExceptionMessage\\\": \\\"\\\", \\\"testCaseExecutionTime\\\": null}, {\\\"testCaseName\\\": \\\"Sample Test\\\", \\\"testCaseResultStatus\\\": \\\"FAILED\\\", \\\"testCaseExceptionMessage\\\": [\\\"Error: expect(received).toBe(expected) // Object.is equality\\\\n\\\\nExpected: 3\\\\nReceived: 2\\\\n    at Object.<anonymous> (/private/tmp/24c1854670aa4c52bcb45516cf1d1d2b/08efb63eeaee49279b6e504abda3d793/src/__tests__/1.test.js:59:19)\\\\n    at Promise.then.completed (/private/tmp/24c1854670aa4c52bcb45516cf1d1d2b/08efb63eeaee49279b6e504abda3d793/node_modules/jest-circus/build/utils.js:276:28)\\\\n    at new Promise (<anonymous>)\\\\n    at callAsyncCircusFn (/private/tmp/24c1854670aa4c52bcb45516cf1d1d2b/08efb63eeaee49279b6e504abda3d793/node_modules/jest-circus/build/utils.js:216:10)\\\\n    at _callCircusTest (/private/tmp/24c1854670aa4c52bcb45516cf1d1d2b/08efb63eeaee49279b6e504abda3d793/node_modules/jest-circus/build/run.js:212:40)\\\\n    at processTicksAndRejections (node:internal/process/task_queues:95:5)\\\\n    at _runTest (/private/tmp/24c1854670aa4c52bcb45516cf1d1d2b/08efb63eeaee49279b6e504abda3d793/node_modules/jest-circus/build/run.js:149:3)\\\\n    at _runTestsForDescribeBlock (/private/tmp/24c1854670aa4c52bcb45516cf1d1d2b/08efb63eeaee49279b6e504abda3d793/node_modules/jest-circus/build/run.js:63:9)\\\\n    at run (/private/tmp/24c1854670aa4c52bcb45516cf1d1d2b/08efb63eeaee49279b6e504abda3d793/node_modules/jest-circus/build/run.js:25:3)\\\\n    at runAndTransformResultsToJestFormat (/private/tmp/24c1854670aa4c52bcb45516cf1d1d2b/08efb63eeaee49279b6e504abda3d793/node_modules/jest-circus/build/legacy-code-todo-rewrite/jestAdapterInit.js:176:21)\\\\n    at jestAdapter (/private/tmp/24c1854670aa4c52bcb45516cf1d1d2b/08efb63eeaee49279b6e504abda3d793/node_modules/jest-circus/build/legacy-code-todo-rewrite/jestAdapter.js:109:19)\\\\n    at runTestInternal (/private/tmp/24c1854670aa4c52bcb45516cf1d1d2b/08efb63eeaee49279b6e504abda3d793/node_modules/jest-runner/build/runTest.js:380:16)\\\\n    at runTest (/private/tmp/24c1854670aa4c52bcb45516cf1d1d2b/08efb63eeaee49279b6e504abda3d793/node_modules/jest-runner/build/runTest.js:472:34)\\\\n    at Object.worker (/private/tmp/24c1854670aa4c52bcb45516cf1d1d2b/08efb63eeaee49279b6e504abda3d793/node_modules/jest-runner/build/testWorker.js:133:12)\\\"], \\\"testCaseExecutionTime\\\": null}]\",\n        \"status\": \"False\",\n        \"points\": 20,\n        \"score\": 0,\n        \"testCaseId\": 64158,\n        \"message\": \"  ● Sample Test\\n\\n    expect(received).toBe(expected) // Object.is equality\\n\\n    Expected: 3\\n    Received: 2\\n\\n      57 |\\n      58 | test('Sample Test', () => {\\n    > 59 |     expect(1 + 1).toBe(3);\\n         |                   ^\\n      60 | });\\n      61 |\\n      62 |\\n\\n      at Object.<anonymous> (src/__tests__/1.test.js:59:19)\\n\",\n        \"testCaseExecutionTime\": 2246\n    }\n]",
            "response": null,
            "expected_response": null,
            "live_run_user_id": null,
            "version": "V3"
        }
    }
};

const a = 'Please wait for a few minutes until your code is being compiled.';
const TESTCASE_STATUS = {
    PASSED: { label: 'Passed', class: 'test-success' },
    SUCCEEDED: { label: 'Passed', class: 'test-success' },
    FAILED: { label: 'Failed', class: 'test-danger' },
    True: { label: 'Passed', class: 'test-success' },
    true: { label: 'Passed', class: 'test-success' },
    False: { label: 'Failed', class: 'test-danger' },
    false: { label: 'Failed', class: 'test-danger' },
};
class CodeSubmissionComponent {
    constructor(cd, apiService, dialogRef, data) {
        this.cd = cd;
        this.apiService = apiService;
        this.dialogRef = dialogRef;
        this.data = data;
        this.testCaseCols = ['testCaseName', 'points', 'score', 'testCaseExecutionTime', 'status', 'actions'];
        this.subTestCaseCols = ['testCaseName', 'testCaseResultStatus', 'testCaseExceptionMessage'];
        this.submission_status_list = {
            UPLOADING: { name: 'UPLOADING', progress: 20, label: 'Uploading your code to the server...', compLabel: 'Code has been successfully uploaded to the server', complete: false },
            SAVING: { name: 'SAVING', progress: 50, label: 'Setting up your code in a workspace (this usually takes around 1-2 minutes)...', compLabel: 'Code has been successfully set up in a workspace', complete: false },
            RUNNING: { name: 'RUNNING', progress: 100, label: 'Test cases executed successfully', compLabel: 'Test cases executed successfully', complete: false },
        };
        this.progress = 0;
        this.loaded = false;
        this.TESTCASE_STATUS = TESTCASE_STATUS;
        this.originalOrder = (a, b) => {
            return 0;
        };
    }
    ngOnInit() {
        const regex = /\.(test|spec)\.(js|ts)$/;
        const files = pickBy(this.data.files, ((value, key) => !regex.test(key)));
        this.subs = AWS.uploadFile({ file: JSON.stringify(files), path: `${this.data.test_uuid}/questions/${this.data.question.id}`, name: 'solution.json' })
            .pipe(tap(() => this.updateStatus(this.submission_status_list.UPLOADING)), mergeMap(response => this.data.type === 'RUN' ? this.saveLiveRun(response.url) : this.saveSubmission(response.url)), tap(() => this.updateStatus(this.submission_status_list.RUNNING)), delay(3000))
            .subscribe(results => {
            var _a;
            if (results.status <= 2) {
                this.results = Object.assign(Object.assign({}, results), { logs: (_a = results.logs) !== null && _a !== void 0 ? _a : 'Request timed-out. Kindly re-submit the solution.' });
            }
            else {
                this.results = results;
            }
            this.loaded = true;
        });
    }
    updateStatus(status) {
        status.complete = true;
        this.progress = status.progress;
    }
    updateError(error, status) {
        status.error = error.error.message;
        return throwError(error);
    }
    closeDialog() {
        this.dialogRef.close(this.results);
    }
    saveLiveRun(workspace_url) {
        return this.apiService.saveLiveRun(this.data.question, this.data.test_uuid, this.data.test_type, this.data.language_id, workspace_url, this.data.portal)
            .pipe(catchError(err => this.updateError(err, this.submission_status_list.SAVING)), 
        // tap(() => this.updateStatus(this.submission_status_list.SAVING)),
        mergeMap((response) => this.apiService.getLiveRunStatus(response.id, this.data.portal, (results) => this.updateRunProgress(results)).pipe(tap(() => this.updateStatus(this.submission_status_list.SAVING)), catchError(err => this.updateError(err, this.submission_status_list.SAVING)))));
    }
    saveSubmission(workspace_url) {
        return this.apiService.saveSubmission(this.data.question, this.data.test_uuid, this.data.test_type, this.data.language_id, workspace_url, this.data.portal)
            .pipe(catchError(err => this.updateError(err, this.submission_status_list.SAVING)), 
        // tap(() => this.updateStatus(this.submission_status_list.SAVING)),
        mergeMap((response) => this.apiService.getSubmisssionStatus(response.id, (results) => this.updateRunProgress(results)).pipe(tap(() => this.updateStatus(this.submission_status_list.SAVING)), catchError(err => this.updateError(err, this.submission_status_list.SAVING)))));
    }
    updateRunProgress(results) {
        this.progress = this.progress < 90 ? this.progress + 4 : this.progress;
        this.cd.markForCheck();
    }
    expandElement(element) {
        this.testCaseElement = this.testCaseElement === element ? null : element;
    }
    expandSubTestCaseElement(element) {
        this.subTestCaseElement = this.subTestCaseElement === element ? null : element;
    }
    ngOnDestroy() {
        var _a;
        (_a = this.subs) === null || _a === void 0 ? void 0 : _a.unsubscribe();
    }
}
CodeSubmissionComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: CodeSubmissionComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: ApiService }, { token: i2.MatDialogRef }, { token: MAT_DIALOG_DATA }], target: i0.ɵɵFactoryTarget.Component });
CodeSubmissionComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: CodeSubmissionComponent, selector: "lib-code-submission", ngImport: i0, template: "<div class=\"popup\">\n    <div class=\"popup__header\">\n        <h5 class=\"title\">Code Submission</h5>\n        <button mat-icon-button color=\"warn\" (click)=\"closeDialog()\">\n            <mat-icon style=\"font-size: 1.7rem !important;\">close</mat-icon>\n        </button>\n    </div>\n    <div class=\"popup__body\">\n        <div *ngIf=\"!loaded\" class=\"progress--stepers\">\n            <div class=\"status-progress\">\n                <mat-progress-bar mode=\"determinate\" [value]=\"progress\"></mat-progress-bar>\n            </div>\n            <div *ngFor=\"let item of submission_status_list|keyvalue:originalOrder\" class=\"status-steppers\">\n                <div class=\"status-steppers__icon\">\n                    <mat-icon *ngIf=\"!item.value['error']\"\n                        [ngClass]=\"{'complete': item.value['complete']}\">check_circle</mat-icon>\n                    <mat-icon *ngIf=\"item.value['error']\" class=\"error\"\n                        [matTooltip]=\"item.value['error']\">cancel</mat-icon>\n                </div>\n                <div class=\"status-steppers__label\">\n                    {{item.value['complete'] ? item.value['compLabel'] : item.value['label']}}\n                </div>\n            </div>\n        </div>\n        <div *ngIf=\"loaded\" class=\"scroll-container\">\n            <div *ngIf=\"results?.output?.length\" class=\"tescases-table\">\n                <mat-table class=\"test-case-details\" [dataSource]=\"results?.output\" multiTemplateDataRows>\n                    <ng-container matColumnDef=\"testCaseName\">\n                        <mat-header-cell *matHeaderCellDef> Exercise Name </mat-header-cell>\n                        <mat-cell *matCellDef=\"let element\">\n                            <div>{{ element.testCaseName }}</div>\n                        </mat-cell>\n                    </ng-container>\n\n                    <ng-container matColumnDef=\"points\">\n                        <mat-header-cell *matHeaderCellDef> Points </mat-header-cell>\n                        <mat-cell *matCellDef=\"let element\">\n                            <div>{{ element.points }}</div>\n                        </mat-cell>\n                    </ng-container>\n\n                    <ng-container matColumnDef=\"score\">\n                        <mat-header-cell *matHeaderCellDef> Score </mat-header-cell>\n                        <mat-cell *matCellDef=\"let element\">\n                            <div>{{ element.score }}</div>\n                        </mat-cell>\n                    </ng-container>\n\n                    <ng-container matColumnDef=\"testCaseExecutionTime\">\n                        <mat-header-cell *matHeaderCellDef> Time(ms) </mat-header-cell>\n                        <mat-cell *matCellDef=\"let element\">\n                            <div>{{ element.testCaseExecutionTime }}</div>\n                        </mat-cell>\n                    </ng-container>\n\n                    <ng-container matColumnDef=\"status\">\n                        <mat-header-cell *matHeaderCellDef> Status </mat-header-cell>\n                        <mat-cell *matCellDef=\"let element\">\n                            <div [ngClass]=\"TESTCASE_STATUS[element.status].class\">\n                                {{ TESTCASE_STATUS[element.status].label }}\n                            </div>\n                        </mat-cell>\n                    </ng-container>\n\n                    <ng-container matColumnDef=\"actions\">\n                        <mat-header-cell *matHeaderCellDef> Actions </mat-header-cell>\n                        <mat-cell *matCellDef=\"let element\">\n                            <div class=\"\">\n                                <button *ngIf=\"element.output?.length || element.message\" mat-icon-button\n                                    (click)=\"expandElement(element)\">\n                                    <mat-icon\n                                        [@rotateAnimation]=\"testCaseElement === element ? false : true\">expand_more\n                                    </mat-icon>\n                                </button>\n                                <div *ngIf=\"!element.output?.length && !element.message\">-</div>\n                            </div>\n                        </mat-cell>\n                    </ng-container>\n\n\n                    <ng-container matColumnDef=\"expandedDetail\">\n                        <td mat-cell *matCellDef=\"let element\" [attr.colspan]=\"testCaseCols.length\"\n                            [@fadeInAnimation]=\"element == testCaseElement ? 'expanded' : 'collapsed'\">\n                            <ng-container *ngIf=\"element.output?.length\" [ngTemplateOutlet]=\"subtestcases\"\n                                [ngTemplateOutletContext]=\"{testcase: element}\"></ng-container>\n\n                            <div *ngIf=\"!element.output?.length && element.message\"\n                                class=\"exception-details exercise-logs\">\n                                <pre [innerHTML]=\"element.message\"></pre>\n                            </div>\n                        </td>\n                    </ng-container>\n\n\n                    <mat-header-row *matHeaderRowDef=\"testCaseCols\"></mat-header-row>\n                    <mat-row class=\"cursor-pointer\" *matRowDef=\"let element; columns: testCaseCols;\">\n                    </mat-row>\n\n                    <mat-row [class.expanded-row]=\"testCaseElement === row\"\n                        *matRowDef=\"let row; columns: ['expandedDetail']\" class=\"expand-detail-row\"></mat-row>\n                </mat-table>\n            </div>\n            <div *ngIf=\"!results?.output?.length && results?.logs\" class=\"logs-container\">\n                <pre [innerHTML]=\"results?.logs\"></pre>\n            </div>\n        </div>\n\n    </div>\n\n    <div class=\"popup__footer\">\n\n    </div>\n</div>\n\n\n<ng-template #subtestcases let-testcase=\"testcase\">\n    <mat-table class=\"subtestcases-table\" [dataSource]=\"testcase.output\" multiTemplateDataRows>\n        <ng-container matColumnDef=\"testCaseName\">\n            <mat-header-cell *matHeaderCellDef> Testcase Name </mat-header-cell>\n            <mat-cell *matCellDef=\"let element\">\n                <div>{{ element.testCaseName }}</div>\n            </mat-cell>\n        </ng-container>\n\n        <ng-container matColumnDef=\"testCaseResultStatus\">\n            <mat-header-cell *matHeaderCellDef> Status </mat-header-cell>\n            <mat-cell *matCellDef=\"let element\">\n                <div [ngClass]=\"TESTCASE_STATUS[element.testCaseResultStatus].class\">\n                    {{ TESTCASE_STATUS[element.testCaseResultStatus].label }}\n                </div>\n            </mat-cell>\n        </ng-container>\n\n        <ng-container matColumnDef=\"testCaseExceptionMessage\">\n            <mat-header-cell *matHeaderCellDef> Exception Message </mat-header-cell>\n            <mat-cell *matCellDef=\"let element\">\n                <div>\n                    <button *ngIf=\"element.testCaseExceptionMessage\" mat-icon-button\n                        (click)=\"expandSubTestCaseElement(element)\">\n                        <mat-icon [@rotateAnimation]=\"subTestCaseElement === element ? false : true\">\n                            expand_more\n                        </mat-icon>\n                    </button>\n                    <div *ngIf=\"!element.testCaseExceptionMessage\">-</div>\n\n                </div>\n            </mat-cell>\n        </ng-container>\n\n        <ng-container matColumnDef=\"expandedDetail\">\n            <td mat-cell *matCellDef=\"let element\" [attr.colspan]=\"subTestCaseCols.length\"\n                [@fadeInAnimation]=\"element == subTestCaseElement ? 'expanded' : 'collapsed'\">\n                <div class=\"exception-details\">\n                    <pre [innerHTML]=\"element.testCaseExceptionMessage\"></pre>\n                </div>\n            </td>\n        </ng-container>\n\n\n        <mat-header-row *matHeaderRowDef=\"subTestCaseCols\"></mat-header-row>\n        <mat-row class=\"cursor-pointer\" *matRowDef=\"let element; columns: subTestCaseCols;\">\n        </mat-row>\n\n        <mat-row [class.expanded-row]=\"subTestCaseElement === row\" *matRowDef=\"let row; columns: ['expandedDetail']\"\n            class=\"expand-detail-row\"></mat-row>\n    </mat-table>\n</ng-template>", styles: [":host .popup{display:flex;flex-direction:column}:host .popup__header{display:flex;align-items:center;justify-content:space-between;height:50px;padding:0 1.5rem;border-bottom:1px solid #ebedf2}:host .popup__header .title{margin:0;padding:0;font-size:1.2em;font-weight:500;color:#48465b}:host .popup__body .progress--stepers{padding:1.5rem}:host .popup__body .scroll-container{overflow:auto;height:calc(80vh - 55px)}:host .popup__body .logs-container{background-color:#000;padding:1rem;color:#fff;word-break:break-word;height:calc(100% - 50px + 2.55rem)}:host .popup__body .logs-container pre{line-height:1.5rem;white-space:break-spaces;color:#fff}:host .popup__body .tescases-table{display:block;overflow-x:auto;height:100%;width:940px}:host .popup__body .tescases-table table{margin-bottom:0}:host .popup__body .tescases-table .mat-row:last-child{border:none}:host .popup__body .tescases-table .test-case-details{table-layout:fixed}:host .popup__body .tescases-table .test-case-details .mat-header-row,:host .popup__body .tescases-table .test-case-details .mat-row{display:flex}:host .popup__body .tescases-table .test-case-details .mat-row,:host .popup__body .tescases-table .test-case-details .mat-header-row{height:unset!important;min-height:3.5em}:host .popup__body .tescases-table .test-case-details .mat-cell{display:inline-flex;align-items:center;font-size:1em;padding:.3rem 20px;font-weight:500}:host .popup__body .tescases-table .test-case-details .mat-header-cell{display:inline-flex;padding:.3rem 20px;font-size:1rem}:host .popup__body .tescases-table .test-case-details .mat-header-cell,:host .popup__body .tescases-table .test-case-details .mat-cell{justify-content:center}:host .popup__body .tescases-table .test-case-details .mat-column-testCaseName{justify-content:flex-start!important;font-weight:400;flex:1 0 20%;max-width:350px}:host .popup__body .tescases-table .test-case-details .mat-column-testCaseName.mat-cell{font-size:1.1rem}:host .popup__body .tescases-table .test-case-details .mat-column-expandedDetail{border:none;padding:0!important;width:100%}:host .popup__body .tescases-table .test-case-details .expand-detail-row{height:unset!important;min-height:unset}:host .popup__body .tescases-table .test-case-details .expand-detail-row:not(.expanded-row){border-bottom-width:0}:host .popup__body .tescases-table .test-case-details .expand-detail-row:not(.expanded-row) .exception-details{display:none}:host .popup__body .tescases-table .test-case-details .exception-details{background-color:#000;padding:1rem;color:#fff;word-break:break-word;max-height:250px;min-height:100px;width:100%;overflow:auto}:host .popup__body .tescases-table .test-case-details .exception-details pre{line-height:1.5rem;white-space:break-spaces;color:#fff;margin:0!important;font-size:1rem!important}:host .popup__body .tescases-table .test-case-details .subtestcases-table{border:1px solid rgba(0,0,0,.12);border-radius:.25rem;margin:1.25rem 3rem;width:100%}:host .popup__body .tescases-table .test-case-details .subtestcases-table .mat-row,:host .popup__body .tescases-table .test-case-details .subtestcases-table .mat-header-row{border:none}:host .popup .status-progress{margin-bottom:25px}:host .popup .mat-progress-bar{height:8px!important;border-radius:4px}:host .popup .mat-progress-bar .mat-progress-bar-fill:after{background-color:#3f51b5}:host .popup .status-steppers{display:flex;align-items:center;justify-content:flex-start;grid-gap:5px;gap:5px;margin-top:15px;padding:0 15px}:host .popup .status-steppers__icon .mat-icon{font-size:22px!important;color:#0000008a}:host .popup .status-steppers__icon .mat-icon.complete{color:#4caf50}:host .popup .status-steppers__icon .mat-icon.error{color:#f44336}:host .popup .status-steppers__label{color:#333;font-size:1.2rem;position:relative;bottom:2px;margin-left:8px}:host .test-success{color:#1ba94c;font-weight:500}:host .test-danger{color:#f44336;font-weight:500}:host .mat-column-testCaseExceptionMessage,:host .mat-column-actions{flex:0 0 20%}:host .mat-column-testCaseExceptionMessage>div:first-child{display:flex;align-items:center;justify-content:center;width:100%}:host .mat-column-testCaseExceptionMessage>div:first-child .exception-title{width:100%;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;font-weight:400}\n"], components: [{ type: i3.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i4.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { type: i5.MatProgressBar, selector: "mat-progress-bar", inputs: ["color", "mode", "value", "bufferValue"], outputs: ["animationEnd"], exportAs: ["matProgressBar"] }, { type: i6.MatTable, selector: "mat-table, table[mat-table]", exportAs: ["matTable"] }, { type: i6.MatHeaderRow, selector: "mat-header-row, tr[mat-header-row]", exportAs: ["matHeaderRow"] }, { type: i6.MatRow, selector: "mat-row, tr[mat-row]", exportAs: ["matRow"] }], directives: [{ type: i7.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i7.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i7.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i8.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { type: i6.MatColumnDef, selector: "[matColumnDef]", inputs: ["sticky", "matColumnDef"] }, { type: i6.MatHeaderCellDef, selector: "[matHeaderCellDef]" }, { type: i6.MatHeaderCell, selector: "mat-header-cell, th[mat-header-cell]" }, { type: i6.MatCellDef, selector: "[matCellDef]" }, { type: i6.MatCell, selector: "mat-cell, td[mat-cell]" }, { type: i7.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }, { type: i6.MatHeaderRowDef, selector: "[matHeaderRowDef]", inputs: ["matHeaderRowDef", "matHeaderRowDefSticky"] }, { type: i6.MatRowDef, selector: "[matRowDef]", inputs: ["matRowDefColumns", "matRowDefWhen"] }], pipes: { "keyvalue": i7.KeyValuePipe }, animations: [fadeInAnimation, rotateAnimation] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: CodeSubmissionComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'lib-code-submission',
                    templateUrl: './code-submission.component.html',
                    styleUrls: ['./code-submission.component.scss'],
                    animations: [fadeInAnimation, rotateAnimation]
                }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }, { type: ApiService }, { type: i2.MatDialogRef }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }]; } });

function generateMonacoTree(input) {
    const output = [];
    for (const key in input) {
        const item = input[key];
        let parts = key.split('/').filter(Boolean);
        let folder = output;
        for (let i = 0; i < parts.length - 1; i++) {
            const existingFolder = folder.find(entry => entry.name === parts[i] && entry.content);
            if (existingFolder) {
                folder = existingFolder.content || [];
            }
            else {
                const newFolder = { name: parts[i], content: [], path: '/' + parts.slice(0, i + 1).join('/') };
                folder.push(newFolder);
                folder = newFolder.content;
            }
        }
        const a = Object.assign({ name: parts[parts.length - 1], path: key }, item);
        if (a.code === null || a.code === undefined) {
            a['content'] = [];
        }
        folder.push(a);
    }
    return sortDirectoriesFirst([{ content: output, path: '/', name: 'root' }]);
}
function sortDirectoriesFirst(arr) {
    const sortedArray = [...arr];
    sortedArray.sort((a, b) => {
        if (a.content && !b.content) {
            return -1; // Place directory before file
        }
        else if (!a.content && b.content) {
            return 1; // Place file after directory
        }
        else {
            return a.name.localeCompare(b.name); // Sort alphabetically
        }
    });
    for (const item of sortedArray) {
        if (item.content) {
            item.content = sortDirectoriesFirst(item.content);
        }
    }
    return sortedArray;
}
function getAllFilePaths(node) {
    if (!node || !node.content) {
        return [];
    }
    const filePaths = [];
    for (const item of node.content) {
        const fullPath = item.path;
        if (item.content && item.content.length > 0) {
            filePaths.push(...getAllFilePaths(item));
        }
        else if (item.path) {
            filePaths.push(fullPath);
        }
    }
    return filePaths;
}
function getParentNode(nodes, path) {
    function findParentRecursive(currentNodes) {
        for (const node of currentNodes) {
            if (node.content && node.content.some(subNode => subNode.path === path)) {
                return node;
            }
            if (node.content) {
                const foundParent = findParentRecursive(node.content);
                if (foundParent) {
                    return foundParent;
                }
            }
        }
        return null;
    }
    return findParentRecursive(nodes);
}
const isFileTypeValid = (filename, fileType) => {
    const allowedFileTypes = ['text'];
    const allowedExt = ['ts', 'tsx', 'jsx', 'js'];
    const ext = filename.split('.').slice(-1)[0];
    if (allowedExt.includes(ext) || allowedFileTypes.some(x => fileType.startsWith(x)))
        return true;
    return false;
};
const readDataFromFile = (file) => {
    return new Promise((resolve, reject) => {
        var reader = new FileReader();
        reader.onload = () => resolve(reader.result);
        reader.readAsText(file);
    });
};

function useEffectAfterMount(cb, dependencies) {
    const mounted = useRef(true);
    useEffect(() => {
        if (!mounted.current) {
            return cb();
        }
        mounted.current = false;
    }, dependencies);
}
;

const getInitialData = (files) => ({ files, visibleFiles: [], activeFile: null });
const useFiles = (props) => {
    const [state, setState] = useState(getInitialData(props.files));
    const [tree, setTree] = useState(generateMonacoTree(state.files));
    const initDone = useRef(false);
    const emitFiles = useRef(false);
    useEffectAfterMount(() => {
        const data = getInitialData(props.files);
        props.onSandboxMount(Object.assign(Object.assign({}, data), operations));
        setState(data);
        updateTree(data.files);
    }, [props.sandboxId]);
    useEffect(() => {
        props.onSandboxMount(Object.assign(Object.assign({}, state), operations));
    }, []);
    useEffectAfterMount(() => {
        if (emitFiles.current) {
            props.onFileChanges(state.files);
        }
    }, [state.files]);
    const updateTree = (files) => setTree(generateMonacoTree(files));
    const addFile = (files, open) => {
        emitFiles.current = true;
        setState((prev) => {
            let activeFile = prev.activeFile;
            let visibleFiles = prev.visibleFiles;
            if (open) {
                const newKeys = keys(files);
                activeFile = newKeys.slice(-1)[0];
                visibleFiles = visibleFiles.includes(activeFile) ? visibleFiles : [...visibleFiles, activeFile];
            }
            const newFiles = Object.assign(Object.assign({}, prev.files), files);
            updateTree(newFiles);
            return Object.assign(Object.assign({}, prev), { files: newFiles, activeFile: activeFile, visibleFiles });
        });
    };
    const operations = {
        openFile: (path) => {
            setState((_a) => {
                var { visibleFiles } = _a, rest = __rest(_a, ["visibleFiles"]);
                const newPaths = visibleFiles.includes(path)
                    ? visibleFiles
                    : [...visibleFiles, path];
                return Object.assign(Object.assign({}, rest), { activeFile: path, visibleFiles: newPaths });
            });
        },
        setActiveFile: (activeFile) => {
            if (state.files[activeFile]) {
                setState((prev) => (Object.assign(Object.assign({}, prev), { activeFile })));
            }
        },
        updateActiveCode: (code) => {
            emitFiles.current = true;
            setState((_a) => {
                var { files, activeFile } = _a, rest = __rest(_a, ["files", "activeFile"]);
                return Object.assign(Object.assign({}, rest), { activeFile, files: Object.assign(Object.assign({}, files), { [activeFile]: Object.assign(Object.assign({}, files[activeFile]), { code }) }) });
            });
        },
        updateFile: (path, data) => {
            emitFiles.current = true;
            setState((_a) => {
                var { files, activeFile } = _a, rest = __rest(_a, ["files", "activeFile"]);
                const newFiles = Object.assign(Object.assign({}, files), { [path]: Object.assign(Object.assign({}, files[path]), data) });
                updateTree(newFiles);
                return Object.assign(Object.assign({}, rest), { activeFile, files: newFiles });
            });
        },
        addFile,
        closeFile: (path) => {
            setState((_a) => {
                var { visibleFiles, activeFile } = _a, prev = __rest(_a, ["visibleFiles", "activeFile"]);
                const indexOfRemovedPath = visibleFiles.indexOf(path);
                const newPaths = visibleFiles.filter((openPath) => openPath !== path);
                return Object.assign(Object.assign({}, prev), { activeFile: path === activeFile
                        ? indexOfRemovedPath === 0
                            ? visibleFiles[1]
                            : visibleFiles[indexOfRemovedPath - 1]
                        : activeFile, visibleFiles: newPaths });
            });
        },
        deleteFile: (path) => {
            emitFiles.current = true;
            setState((_a) => {
                var { visibleFiles, files, activeFile } = _a, rest = __rest(_a, ["visibleFiles", "files", "activeFile"]);
                const newFiles = Object.assign({}, files);
                delete newFiles[path];
                const remainingVisibleFiles = visibleFiles.filter((openPath) => openPath !== path);
                updateTree(newFiles);
                return Object.assign(Object.assign({}, rest), { visibleFiles: remainingVisibleFiles, activeFile: path === activeFile ? remainingVisibleFiles.slice(-1)[0] : activeFile, files: newFiles });
            });
        },
        renameFile: (oldPath, newPath) => {
            emitFiles.current = true;
            setState((_a) => {
                var { visibleFiles, files, activeFile } = _a, rest = __rest(_a, ["visibleFiles", "files", "activeFile"]);
                const newFiles = Object.assign({}, files);
                const existdata = newFiles[oldPath];
                delete newFiles[oldPath];
                newFiles[newPath] = existdata;
                const newVisibleFiles = visibleFiles.map((openPath) => openPath === oldPath ? newPath : openPath);
                updateTree(newFiles);
                return Object.assign(Object.assign({}, rest), { visibleFiles: newVisibleFiles, activeFile: oldPath === activeFile ? newPath : activeFile, files: newFiles });
            });
        },
        renameFolder: (nodePath, oldPath, node) => {
            emitFiles.current = true;
            setState((_a) => {
                var { visibleFiles, files, activeFile } = _a, rest = __rest(_a, ["visibleFiles", "files", "activeFile"]);
                const newFiles = Object.assign({}, files);
                const childFiles = getAllFilePaths(node);
                if (childFiles === null || childFiles === void 0 ? void 0 : childFiles.length) {
                    childFiles.forEach(oldFilePath => {
                        const newFilePath = `${nodePath}/${oldFilePath.split('/').filter(Boolean).pop()}`;
                        const visibleIndex = visibleFiles.indexOf(oldFilePath);
                        if (visibleIndex !== -1) {
                            visibleFiles[visibleIndex] = newFilePath;
                        }
                        const exitData = newFiles[oldFilePath];
                        delete newFiles[oldFilePath];
                        newFiles[newFilePath] = exitData;
                        activeFile = activeFile === oldFilePath ? newFilePath : activeFile;
                    });
                }
                else {
                    delete newFiles[oldPath];
                    newFiles[nodePath] = {};
                }
                updateTree(newFiles);
                return Object.assign(Object.assign({}, rest), { visibleFiles,
                    activeFile, files: newFiles });
            });
        },
        addFolder: (path) => {
            addFile({ [path]: {} });
        },
        deleteFolder: (nodePath, node) => {
            emitFiles.current = true;
            setState((_a) => {
                var { visibleFiles, files, activeFile } = _a, rest = __rest(_a, ["visibleFiles", "files", "activeFile"]);
                const newFiles = Object.assign({}, files);
                const childFiles = getAllFilePaths(node);
                if (childFiles === null || childFiles === void 0 ? void 0 : childFiles.length) {
                    childFiles.forEach(oldFilePath => {
                        const visibleIndex = visibleFiles.indexOf(oldFilePath);
                        if (visibleIndex !== -1) {
                            visibleFiles.splice(visibleIndex, 1);
                        }
                        delete newFiles[oldFilePath];
                    });
                }
                else {
                    delete newFiles[nodePath];
                }
                updateTree(newFiles);
                return Object.assign(Object.assign({}, rest), { visibleFiles, activeFile: childFiles.includes(activeFile) ? visibleFiles.slice(-1)[0] : activeFile, files: newFiles, tree: generateMonacoTree(newFiles) });
            });
        },
        uploadFiles: (filelist, nodePath) => __awaiter(void 0, void 0, void 0, function* () {
            nodePath = nodePath === '/' ? '' : nodePath;
            if (filelist.length) {
                const newFiles = {};
                for (let index = 0; index < filelist.length; index++) {
                    const file = filelist[index];
                    if (isFileTypeValid(file.name, file.type)) {
                        const code = yield readDataFromFile(file);
                        newFiles[`${nodePath}/${file['webkitRelativePath'] || file.name}`] = { code };
                    }
                }
                addFile(newFiles);
            }
        }),
        runCode() {
            props.onRunCode(state.files);
        },
        submitCode() {
            props.onSubmitCode(state.files);
        }
    };
    return [Object.assign({}, state), operations, tree];
};

const SandboxReactContext = createContext(undefined);
const SandboxProvider = (props) => {
    const [focusedNode, setFocusedNode] = useState();
    const [fileState, fileOperations, tree] = useFiles(props);
    const [theme, setTheme] = useState(props.theme || 'light');
    useEffect(() => {
        setFocusedNode(tree[0]);
    }, []);
    const contextValue = {
        sandbox: Object.assign(Object.assign({}, fileState), fileOperations),
        props,
        focusedNode,
        setFocusedNode,
        theme,
        setTheme,
        tree
    };
    return (React__default.createElement(SandboxReactContext.Provider, { value: contextValue }, props.children));
};

function useSandbox() {
    const context = React.useContext(SandboxReactContext);
    if (!context) {
        throw new Error('useSandbox must be used within a SandboxProvider');
    }
    return context;
}

const SandboxTemplates = {
    react: {
        name: 'react',
        dn: 'React',
        icon: 'https://cdn.jsdelivr.net/npm/material-icon-theme@3.7.1/icons/react.svg',
        description: 'lorem ipsum',
        boilerplateCodeS3Url: 'https://codejudge-proctoring-dev-v2.s3.us-east-1.amazonaws.com/2605124f844448b28022fdff00428946/questions/3776/1693984585109--6efee863-1755-4bc4-939b-3a4c1ad67c5f--solution.json',
        testFilePath: '/src/__tests__/{{testFilename}}.test.js'
    },
    vanilla: {
        name: 'vanilla',
        dn: 'Javascript',
        icon: 'https://cdn.jsdelivr.net/npm/material-icon-theme@3.7.1/icons/javascript.svg',
        description: 'lorem ipsum',
        boilerplateCodeS3Url: 'https://codejudge-proctoring-dev-v2.s3.us-east-1.amazonaws.com/2605124f844448b28022fdff00428946/questions/3776/1693983937815--5f1dcd5c-74b2-4431-b878-4eaeb3b77278--solution.json',
        testFilePath: '/__tests__/{{testFilename}}.test.js'
    }
};
const other = {
    'vanilla-ts': {},
    'react-ts': {},
};

const { createTheme, css, getCssText, keyframes, } = createStitches({
    prefix: 'sp'
});
const sandpackMainContainer = css({
    // boxShadow: '0 6px 16px 0 rgba(0,0,0,.2)',
    border: 'none !important'
});
const iconStandaloneClassName = css({
    svg: { margin: "auto" },
});
const buttonClassName = css({
    appearance: "none",
    outline: "none",
    display: "flex",
    alignItems: "center",
    fontSize: "inherit",
    fontFamily: "inherit",
    backgroundColor: "transparent",
    transition: "color $default, background $default",
    cursor: "pointer",
    color: "$colors$clickable",
    border: 0,
    textDecoration: "none",
    "&:disabled": { color: "$colors$disabled" },
    "&:hover:not(:disabled,[data-active='true'])": { color: "$colors$hover" },
    '&[data-active="true"]': { color: "$colors$accent" },
    img: {
        minWidth: "$space$4",
        width: "$space$4",
        height: "$space$4",
    },
    [`&.${iconStandaloneClassName}`]: {
        padding: "$space$1",
        height: "$space$7",
        display: "flex",
    },
    // If there's a children besides the icon
    [`&.${iconStandaloneClassName}&:not(:has(span))`]: {
        width: "$space$7",
    },
    [`&.${iconStandaloneClassName}&:has(svg + span)`]: {
        paddingRight: "$space$3",
        paddingLeft: "$space$2",
        gap: "$space$1",
    },
    '&.sp-FileManager-action': {
        padding: '4px',
        fontSize: '15px'
    }
});
const placeholderClassName = css({
    margin: "0",
    display: "block",
    fontFamily: "$font$mono",
    fontSize: "$font$size",
    color: "$syntax$color$plain",
    lineHeight: "$font$lineHeight",
});
const tabButton$1 = css({
    padding: "0 $space$2",
    height: "$layout$headerHeight",
    whiteSpace: "nowrap",
    "&:focus": { outline: "none" },
});
const runButton = css({
    color: "#116de3",
    backgroundColor: "#fff",
    border: "1px solid #116de3"
});
const submitButton = css({
    color: "#fff",
    backgroundColor: "#116de3",
});
const actionButtons = css({
    display: "inline-block",
    textAlign: "center",
    boxSizing: "border-box",
    whiteSpace: "nowrap",
    verticalAlign: "middle",
    userSelect: "none",
    borderRadius: "4px",
    color: "#fff",
    cursor: "pointer",
    border: "1px solid transparent",
    fontSize: "14px", lineHeight: "16px", padding: "6px 15px",
    fontWeight: 600
});
const consoleContainerStyle = css({
    '.console-tabs': {
        height: '40px',
        display: 'flex',
        justifyContent: 'space-between',
        background: "$colors$surface1",
        borderBottom: "1px solid $colors$surface2",
        ".console-tabs__actions": {
            display: 'flex',
            justifyContent: 'space-between',
            alignItems: 'center',
            padding: "0 24px",
            gap: '10px'
        }
    },
    '.console-view': {
        height: 'calc(100% - 40px)',
        overflow: 'auto'
    },
    '.console-tabs__tabs-label': {
        height: "40px",
        padding: "0 24px",
        cursor: "pointer",
        opacity: 0.6,
        display: "inline-flex",
        justifyContent: "flex-start",
        alignItems: "center",
        textDecoration: 'none'
    }
});

const tabsClassName = css({
    borderBottom: "1px solid $colors$surface2",
    background: "$colors$surface1",
    minHeight: '$layout$headerHeight',
    display: 'flex',
    alignItems: 'center'
});
const tabsScrollableClassName = css({
    overflow: "auto",
    display: "flex",
    flexWrap: "nowrap",
    alignItems: "stretch",
    padding: 0,
    height: '100%',
    flex: 1
});
const closeButtonClassName = css({
    padding: "0 $space$1 0 $space$1",
    borderRadius: "$border$radius",
    width: "$space$5",
    svg: {
        width: "$space$3",
        height: "$space$3",
        display: "block",
        position: "relative",
        top: 1,
    },
});
const tabButton = css({
    padding: "0 $space$2",
    gap: 5,
    whiteSpace: "nowrap",
    borderRight: '1px solid $colors$surface2',
    position: 'relative',
    '&[data-active="true"]': {
        color: "$colors$clickable",
    },
    "&:focus": { outline: "none" },
    '.tab-active': {
        width: '100%',
        height: 3,
        position: 'absolute',
        right: 0,
        left: 0,
        top: 0,
        background: '$colors$accent'
    }
});
const FileTabs = () => {
    const { sandbox, props } = useSandbox();
    const classNames = useClassNames();
    const [tabs, setTabs] = useState([]);
    useEffect(() => {
        const tabs = sandbox.visibleFiles.map(path => ({ label: path.split('/').filter(Boolean).pop(), path }));
        setTabs(tabs);
    }, [sandbox.visibleFiles]);
    const handleCloseFile = (ev, path) => {
        ev.stopPropagation();
        sandbox.closeFile(path);
    };
    const getIcon = (fileName) => {
        const IconPath = (icon) => React__default.createElement("img", { className: "monaco-tree-icon", src: `https://cdn.jsdelivr.net/npm/material-icon-theme@3.7.1/icons/${icon}` });
        const fileIcon = getIconForFile(fileName);
        return IconPath(fileIcon);
    };
    return (React__default.createElement("div", { className: classNames("tabs", [tabsClassName]) },
        React__default.createElement("div", { "aria-label": "Select active file", className: classNames("tabs-scrollable-container", [
                tabsScrollableClassName,
            ]), role: "tablist" }, tabs.map(({ path, label }) => (React__default.createElement("button", { key: path, "aria-selected": path === sandbox.activeFile, className: classNames("tab-button", [buttonClassName, tabButton]), "data-active": path === sandbox.activeFile, onClick: () => sandbox.setActiveFile(path), role: "tab", title: path, type: "button" },
            path === sandbox.activeFile && React__default.createElement("div", { className: "tab-active" }),
            getIcon(label),
            React__default.createElement("span", null, label),
            React__default.createElement("span", { className: classNames("close-button", [closeButtonClassName]), onClick: (event) => handleCloseFile(event, path) },
                React__default.createElement(CloseIcon, null))))))));
};

const useActiveCode = () => {
    var _a, _b, _c;
    const { sandbox } = useSandbox();
    return {
        code: (_a = sandbox.files[sandbox.activeFile]) === null || _a === void 0 ? void 0 : _a.code,
        readOnly: (_c = (_b = sandbox.files[sandbox.activeFile]) === null || _b === void 0 ? void 0 : _b.readOnly) !== null && _c !== void 0 ? _c : false,
        updateCode: sandbox.updateActiveCode,
    };
};

const DEFAULT_EDITOR_OPTIONS = {
    wordWrap: 'on',
    minimap: { enabled: false },
    roundedSelection: true,
    tabCompletion: 'on',
    scrollBeyondLastLine: true,
    overviewRulerBorder: false,
    glyphMargin: false,
    fixedOverflowWidgets: true,
    renderWhitespace: 'all',
    inlayHints: { enabled: 'off' },
    contextmenu: false,
    wrappingIndent: 'indent',
    fontFamily: `'Monaco', 'Menlo', 'Ubuntu Mono', 'Consolas', 'source-code-pro', monospace`,
    codeLens: false,
    lineNumbers: 'on',
    lightbulb: { enabled: false },
};

const editorClassName = css({
    flex: 1,
    position: "relative",
    overflow: "auto",
    background: "$colors$surface1"
});
function MonacoEditor(props) {
    const classNames = useClassNames();
    return React__default.createElement("div", { className: classNames("code-editor", [editorClassName]) },
        React__default.createElement(Editor, Object.assign({}, props, { options: Object.assign(Object.assign({}, DEFAULT_EDITOR_OPTIONS), props.options), ref: props.onEditorMount })));
}

const noFileStyles = css({
    height: "100%",
    width: "100%",
    display: "flex",
    alignItems: "center",
    justifyContent: "center",
    flexDirection: 'column',
    p: {
        opacity: 0.5,
        margin: '20px 0',
        fontSize: '1.3rem'
    },
    img: {
        height: 30
    }
});
function SandboxEditor(props) {
    var _a;
    const classNames = useClassNames();
    const { code, updateCode, readOnly } = useActiveCode();
    const { sandbox, theme } = useSandbox();
    const editorRef = useRef(null);
    const [value, setValue] = useState('');
    useEffect(() => {
        monaco.editor.setTheme(theme === 'dark' ? 'Default Dark+' : 'Default Light+');
    }, [theme]);
    // useEffect(() => {
    //     editorRef.current?.getModel()?.setValue(code);
    // }, [sandbox.activeFile]);
    return React__default.createElement(SandpackStack, Object.assign({ style: { height: '100%' }, className: classNames("editor", []) }, props),
        React__default.createElement(FileTabs, null),
        !!((_a = sandbox.files) === null || _a === void 0 ? void 0 : _a[sandbox.activeFile]) ?
            React__default.createElement(MonacoEditor, { onEditorMount: (editor => editorRef.current = editor), fileUri: `${props.id}/${sandbox.activeFile}`, key: sandbox.activeFile, value: code, options: { readOnly }, onChange: (value) => updateCode(value) }) :
            React__default.createElement("div", { className: classNames("no-file-open", [noFileStyles]) },
                React__default.createElement("img", { src: "https://dd2jv4x84axh4.cloudfront.net/enterprise-logo-preprod/a667c197-5d9c-4c3d-9050-5d017019f320/codejudge_logo.png" }),
                React__default.createElement("p", { className: "fe-no-file-open-text" },
                    React__default.createElement("span", { className: "fe-left-arrow-emoji" }, " \u2B05 "),
                    " Open a file to get started")));
}

const styles$2 = css({
    ul: {
        listStyle: 'none',
        padding: 0,
        margin: 0
    },
    li: {
        minHeight: "32px",
        color: "rgb(153, 153, 153)",
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'space-between',
    },
    '.dependency-title': {
        maxWidth: '60%',
        overflow: "hidden",
        textOverflow: "ellipsis",
        whiteSpace: "nowrap",
        color: "$colors$clickable"
    },
    '.dependency-actions': {
        display: 'flex',
        alignItems: 'center',
        gap: '4px',
        '.delete-btn': {
            padding: "4px 8px",
            backgroundColor: "transparent",
            color: "rgb(153, 153, 153)",
            width: "100%",
            border: "none",
            display: "inline-flex",
            justifyContent: "center",
            alignItems: "center",
            cursor: 'pointer',
            '&:hover': {
                color: 'rgb(230, 230, 230)'
            }
        }
    }
});
const reactSelectStyles$1 = {
    control: (base) => (Object.assign(Object.assign({}, base), { minHeight: '28px', marginBottom: '8px', cursor: 'text' })),
    indicatorsContainer: () => ({ display: 'none' })
};
const promiseOptions = (inputValue) => {
    return fetch("https://registry.npmjs.com/-/v1/search?text=".concat(inputValue, "&size=5")).then((function (e) {
        return __awaiter(this, void 0, void 0, function* () {
            const data = yield e.json();
            return data.objects.map(t => ({
                label: t.package.name,
                value: t.package.name,
                version: t.package.version
            }));
        });
    }));
};
function DependencyManager() {
    const classNames = useClassNames();
    const { sandbox } = useSandbox();
    const [dependencies, setDependencies] = useState({});
    const [selectedValue, setSelectedValue] = useState(null);
    const loadOptions = useCallback(debounce((inputText, callback) => {
        promiseOptions(inputText).then((options) => callback(options));
    }, 400), []);
    const addDependency = (e) => {
        var _a, _b;
        let pkgJson = sandbox.files['/package.json'];
        if (pkgJson) {
            try {
                pkgJson = JSON.parse(pkgJson.code);
                const dependencies = (_a = pkgJson.dependencies) !== null && _a !== void 0 ? _a : {};
                dependencies[e.value] = e.version;
                sandbox.updateFile('/package.json', { code: JSON.stringify(pkgJson, null, 2) });
                setDependencies((_b = pkgJson.dependencies) !== null && _b !== void 0 ? _b : {});
                setSelectedValue(null);
            }
            catch (error) {
            }
        }
    };
    useEffect(() => {
        updateDependencyList();
    }, []);
    const updateDependencyList = () => {
        var _a;
        let pkgJson = sandbox.files['/package.json'];
        if (pkgJson) {
            try {
                pkgJson = JSON.parse(pkgJson.code);
                setDependencies((_a = pkgJson.dependencies) !== null && _a !== void 0 ? _a : {});
            }
            catch (error) {
            }
        }
    };
    const removeDependency = (dependency) => {
        var _a, _b;
        let pkgJson = sandbox.files['/package.json'];
        if (pkgJson) {
            try {
                pkgJson = JSON.parse(pkgJson.code);
                const dependencies = (_a = pkgJson.dependencies) !== null && _a !== void 0 ? _a : {};
                delete dependencies[dependency];
                sandbox.updateFile('/package.json', { code: JSON.stringify(pkgJson, null, 2) });
                setDependencies((_b = pkgJson.dependencies) !== null && _b !== void 0 ? _b : {});
            }
            catch (error) {
            }
        }
    };
    return React__default.createElement("div", { className: classNames(`dependency-manager`, [styles$2]) },
        React__default.createElement(AsyncSelect, { value: selectedValue, placeholder: 'Add Dependency', styles: reactSelectStyles$1, noOptionsMessage: () => null, loadOptions: loadOptions, onChange: (e) => addDependency(e) }),
        React__default.createElement("ul", null,
            " ",
            Object.keys(dependencies).map(x => {
                return React__default.createElement("li", { key: x },
                    React__default.createElement("div", { className: 'dependency-title' }, x),
                    React__default.createElement("div", { className: 'dependency-actions' },
                        React__default.createElement("div", null,
                            " ",
                            dependencies[x]),
                        React__default.createElement("button", { className: classNames('delete-btn', [buttonClassName]), type: "button", onClick: () => removeDependency(x) },
                            React__default.createElement("svg", { fill: "currentColor", preserveAspectRatio: "xMidYMid meet", height: "1em", width: "1em", viewBox: "0 0 40 40" },
                                React__default.createElement("g", null,
                                    React__default.createElement("path", { d: "m31.6 10.7l-9.3 9.3 9.3 9.3-2.3 2.3-9.3-9.3-9.3 9.3-2.3-2.3 9.3-9.3-9.3-9.3 2.3-2.3 9.3 9.3 9.3-9.3z" }))))));
            })));
}

const FileManagerAction = (props) => {
    const folderUploadInput = useRef(null);
    const fileUploadInput = useRef(null);
    const classNames = useClassNames();
    const { sandbox: { uploadFiles }, focusedNode } = useSandbox();
    useEffect(() => {
        if (folderUploadInput.current !== null) {
            folderUploadInput.current.setAttribute("directory", "");
            folderUploadInput.current.setAttribute("webkitdirectory", "");
            folderUploadInput.current.setAttribute("mozdirectory", "");
        }
    }, [folderUploadInput]);
    const setAddFile = (event) => {
        event.stopPropagation();
        props.setAddFile(true);
    };
    const setAddFolder = (event) => {
        event.stopPropagation();
        props.setAddFolder(true);
    };
    const handleFileChange = (event) => __awaiter(void 0, void 0, void 0, function* () {
        event.stopPropagation();
        uploadFiles(event.target.files, focusedNode.path);
    });
    const openFolderUpload = (event) => {
        event.stopPropagation();
        folderUploadInput.current.click();
    };
    const openFileUpload = (event) => {
        event.stopPropagation();
        fileUploadInput.current.click();
    };
    return React.createElement(React.Fragment, null,
        React.createElement(Tooltip, { placement: "bottom", content: "Add File", delay: 0 },
            React.createElement("button", { className: classNames('FileManager-action', [buttonClassName]), onClick: setAddFile },
                React.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", width: "1em", height: "1em", fill: "currentColor", viewBox: "0 0 16 16" },
                    React.createElement("path", { fillRule: "evenodd", d: "m9.5 1.1 3.4 3.5.1.4v2h-1V6H8V2H3v11h4v1H2.5l-.5-.5v-12l.5-.5h6.7l.3.1zM9 2v3h2.9L9 2zm4 14h-1v-3H9v-1h3V9h1v3h3v1h-3v3z", clipRule: "evenodd" })))),
        React.createElement(Tooltip, { placement: "bottom", content: "Add Folder", delay: 0 },
            React.createElement("button", { className: classNames('FileManager-action', [buttonClassName]), onClick: setAddFolder },
                React.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", width: "1em", height: "1em", fill: "currentColor", viewBox: "0 0 16 16" },
                    React.createElement("path", { fillRule: "evenodd", d: "M14.5 2H7.71l-.85-.85L6.51 1h-5l-.5.5v11l.5.5H7v-1H1.99V6h4.49l.35-.15.86-.86H14v1.5l-.001.51h1.011V2.5L14.5 2zm-.51 2h-6.5l-.35.15-.86.86H2v-3h4.29l.85.85.36.15H14l-.01.99zM13 16h-1v-3H9v-1h3V9h1v3h3v1h-3v3z", clipRule: "evenodd" })))),
        React.createElement(Tooltip, { placement: "bottom", content: "Upload File", delay: 0 },
            React.createElement("button", { className: classNames('FileManager-action', [buttonClassName]), onClick: openFileUpload },
                React.createElement("input", { style: { display: 'none' }, ref: fileUploadInput, type: "file", onChange: handleFileChange }),
                React.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", width: "1em", height: "1em", fill: "currentColor", viewBox: "0 0 32 32" },
                    React.createElement("path", { d: "M26.29,6.88,23.12,3.71A5.85,5.85,0,0,0,19,2H9A5,5,0,0,0,4,7V25a5,5,0,0,0,5,5H23a5,5,0,0,0,5-5V11A5.79,5.79,0,0,0,26.29,6.88ZM24.88,8.29a4.24,4.24,0,0,1,.43.52L25.4,9A3.92,3.92,0,0,1,25.85,10H21a1,1,0,0,1-1-1V4.15a3.36,3.36,0,0,1,.45.14h0a4.08,4.08,0,0,1,.58.32l.14.09a3.42,3.42,0,0,1,.52.42ZM23,28H9a3,3,0,0,1-3-3V7A3,3,0,0,1,9,4h9V9a3,3,0,0,0,3,3h5V25A3,3,0,0,1,23,28Z" }),
                    React.createElement("path", { d: "M22,22a1,1,0,0,0-1,1,1,1,0,0,1-1,1H12a1,1,0,0,1-1-1,1,1,0,0,0-2,0,3,3,0,0,0,3,3h8a3,3,0,0,0,3-3A1,1,0,0,0,22,22Z" }),
                    React.createElement("path", { d: "M13.71,18.36,15,17.06V21a1,1,0,0,0,2,0V17.06l1.29,1.3a1,1,0,0,0,1.42,0,1,1,0,0,0,0-1.42l-2.4-2.4A1.86,1.86,0,0,0,16.16,14a.44.44,0,0,0-.32,0,1.86,1.86,0,0,0-1.15.51l-2.4,2.4a1,1,0,0,0,1.42,1.42Z" })))),
        React.createElement(Tooltip, { placement: "bottom", content: "Upload Folder", delay: 0 },
            React.createElement("button", { className: classNames('FileManager-action', [buttonClassName]), onClick: openFolderUpload },
                React.createElement("input", { style: { display: 'none' }, ref: folderUploadInput, type: "file", onChange: handleFileChange, accept: "text/*" }),
                React.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", width: "1em", height: "1em", fill: "currentColor", viewBox: "0 0 32 32" },
                    React.createElement("path", { d: "M22,20a1,1,0,0,0-1,1,1,1,0,0,1-1,1H12a1,1,0,0,1-1-1,1,1,0,0,0-2,0,3,3,0,0,0,3,3h8a3,3,0,0,0,3-3A1,1,0,0,0,22,20Z", fill: "currentColor" }),
                    React.createElement("path", { d: "M13.71,16.36,15,15.06V19a1,1,0,0,0,2,0V15.06l1.29,1.3a1,1,0,0,0,1.42,0,1,1,0,0,0,0-1.42l-2.4-2.4A1.83,1.83,0,0,0,16,12h0a1.83,1.83,0,0,0-1.3.54l-2.4,2.4a1,1,0,0,0,1.42,1.42Z", fill: "currentColor" }),
                    React.createElement("path", { d: "M25,4H7A5,5,0,0,0,2,9V23a5,5,0,0,0,5,5H25a5,5,0,0,0,5-5V9A5,5,0,0,0,25,4Zm3,5V9a4.92,4.92,0,0,0-3-1H16.92A3.05,3.05,0,0,1,14.3,6.44c-.1-.15-.2-.3-.31-.44H25A3,3,0,0,1,28,9Zm0,14a3,3,0,0,1-3,3H7a3,3,0,0,1-3-3V9A3,3,0,0,1,7,6h3a3,3,0,0,1,2.58,1.47A5.06,5.06,0,0,0,16.92,10H25a3,3,0,0,1,3,3Z", fill: "currentColor" })))));
};
const FileActions = ({ setIsEdit, isFolder, path, row }) => {
    const { sandbox: { deleteFile, deleteFolder } } = useSandbox();
    const classNames = useClassNames();
    const remove = () => {
        if (!isFolder) {
            deleteFile(path);
        }
        else {
            deleteFolder(path, row);
        }
    };
    return (React.createElement(React.Fragment, null,
        React.createElement("span", { className: classNames('FileItem-action', [buttonClassName]), "aria-label": "Rename", onClick: () => setIsEdit(true) },
            React.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", width: "1em", height: "1em", fill: "currentColor", viewBox: "0 0 16 16" },
                React.createElement("path", { d: "M13.23 1h-1.46L3.52 9.25l-.16.22L1 13.59 2.41 15l4.12-2.36.22-.16L15 4.23V2.77L13.23 1zM2.41 13.59l1.51-3 1.45 1.45-2.96 1.55zm3.83-2.06L4.47 9.76l8-8 1.77 1.77-8 8z" }))),
        React.createElement("span", { className: classNames('FileItem-action', [buttonClassName]), "aria-label": "Remove", onClick: remove },
            React.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", width: "1em", height: "1em", fill: "currentColor", viewBox: "0 0 16 16" },
                React.createElement("path", { fillRule: "evenodd", d: "M10 3h3v1h-1v9l-1 1H4l-1-1V4H2V3h3V2a1 1 0 0 1 1-1h3a1 1 0 0 1 1 1v1zM9 2H6v1h3V2zM4 13h7V4H4v9zm2-8H5v7h1V5zm1 0h1v7H7V5zm2 0h1v7H9V5z", clipRule: "evenodd" })))));
};

const ERROR = {
    ALREADY_EXIST: 'File or folder {{file_name}} already exists at this location',
    EMPTY_FILE: 'File name must be specified',
    EMPTY_FOLDER: 'Folder name must be specified',
};
const styles$1 = css({
    flex: 1,
    textAlign: 'left',
    input: {
        maxWidth: "100%",
        display: "block",
        width: "100%",
        padding: "3px 3px 4px 3px",
        backgroundClip: "padding-box",
        border: "1px solid #ced4da",
        borderRadius: "4px",
        lineHeight: '16px !important',
        transition: "border-color .15s ease-in-out,box-shadow .15s ease-in-out",
    },
    'input:focus-visible': {
        outline: '-webkit-focus-ring-color auto 1px'
    },
    position: 'relative',
    '.error': {
        position: 'absolute',
        display: 'block',
        maxWidth: '100%',
        background: '$colors$errorSurface',
        color: '$colors$error',
        borderBottomLeftRadius: "3px",
        borderBottomRightRadius: "3px",
        padding: "5px 5px 10px",
        zIndex: 9,
        border: '1px solid $colors$error'
    }
});
const SingleInputForm = (_a) => {
    var { currentPath, onBlur, filename, isFile, isEdit, row } = _a, props = __rest(_a, ["currentPath", "onBlur", "filename", "isFile", "isEdit", "row"]);
    const [value, setValue] = useState(filename);
    const { sandbox: { renameFile, addFile, renameFolder, addFolder }, tree } = useSandbox();
    const [parentRow, setParentRow] = useState();
    const [error, setError] = useState();
    const classNames = useClassNames();
    useEffectAfterMount(() => {
        const valid = isValid();
        setError(valid.errror);
    }, [value]);
    useEffect(() => {
        setParentRow(isEdit ? row.path === '/' ? tree[0] : getParentNode(tree, row.path) : row);
    }, [tree]);
    const isValid = () => {
        let copyValue = value === null || value === void 0 ? void 0 : value.trim();
        copyValue = copyValue === null || copyValue === void 0 ? void 0 : copyValue.split('/').filter(Boolean).join('/');
        if (!copyValue) {
            return { valid: false, errror: !isFile ? ERROR.EMPTY_FOLDER : ERROR.EMPTY_FILE };
        }
        if (copyValue !== filename && parentRow) {
            const valid = parentRow.content.every(x => x.name !== copyValue);
            return { valid, errror: !valid && Mustache.render(ERROR.ALREADY_EXIST, { file_name: copyValue }) };
        }
        else {
            return { valid: true };
        }
    };
    const handleSubmit = (event) => event.preventDefault();
    const handleBlur = () => {
        let valueOverride = value === null || value === void 0 ? void 0 : value.trim();
        valueOverride = valueOverride === null || valueOverride === void 0 ? void 0 : valueOverride.split('/').filter(Boolean).join('/');
        if (isValid().valid && filename !== valueOverride) {
            const newPath = '/' + (`${parentRow.path}/${valueOverride}`).split('/').filter(Boolean).join('/');
            if (isFile) {
                if (isEdit) {
                    renameFile(currentPath, newPath);
                }
                else {
                    addFile({ [newPath]: { code: '' } });
                }
            }
            else {
                if (isEdit) {
                    renameFolder(newPath, currentPath, row);
                }
                else {
                    addFolder(newPath);
                }
            }
        }
        onBlur(false);
    };
    const onClick = (event) => {
        event.stopPropagation();
    };
    const handleKeyDown = (event) => {
        if (!isValid().valid) {
            return;
        }
        if (event.key === 'Enter') {
            event.preventDefault();
            handleBlur();
        }
        if (event.key === 'Escape') {
            event.preventDefault();
            handleBlur();
        }
    };
    return (React__default.createElement("form", { onSubmit: handleSubmit, className: classNames('file-input', [styles$1]) },
        React__default.createElement("input", { style: {
                maxWidth: '100%',
                border: `1px solid ${error ? 'red' : 'inherit'}`,
            }, onBlur: handleBlur, maxLength: 35, autoFocus: true, placeholder: `${!isFile ? 'Directory name' : 'File name'}`, name: "name", type: "text", value: value, onChange: (e) => setValue(e.target.value), onKeyDown: handleKeyDown, onClick: onClick }),
        error && React__default.createElement("span", { className: 'error', dangerouslySetInnerHTML: { __html: error } })));
};

const monacoTreeStyles = css({
    position: 'relative',
    '.monaco-tree-row': {
        fontSize: "inherit",
        fontFamily: "inherit",
        backgroundColor: "transparent",
        transition: "color $default, background $default",
        cursor: "pointer",
        color: "$colors$clickable",
        lineHeight: "24px",
        display: "flex",
        gridGap: "6px",
        gap: "6px",
        marginBottom: "6px",
        position: "relative",
        userSelect: 'none',
        alignItems: 'center',
        "&:hover:not([data-active='true'])": { color: "$colors$hover" },
        '&[data-active="true"]': { color: "$colors$accent" },
    },
    '.monaco-tree-icon': {
        width: "16px", height: "22px"
    },
    svg: {
        width: "16px", height: "22px"
    },
    '.monaco-tree-name': {
        textOverflow: "ellipsis",
        whiteSpace: "nowrap",
        overflow: "hidden",
        flex: "1 1 0%",
        textAlign: "left"
    },
    [`&:hover:not(.editing) .monaco-tree-actions`]: {
        opacity: 1,
        display: "flex",
    },
    '.monaco-tree-actions': {
        alignItems: "center",
        background: "$colors$surface1",
        bottom: "0",
        display: "none",
        opacity: 0,
        padding: "0 2px",
        position: "absolute",
        right: "0",
        top: "0",
        gap: '4px',
        '.sp-FileItem-action': {
            padding: '4px',
        }
    }
});
const MonacoFileTree = (_a) => {
    var _b, _c;
    var { row, depth = 0, hide = false, clickFile, activeFile, root } = _a, props = __rest(_a, ["row", "depth", "hide", "clickFile", "activeFile", "root"]);
    const [isFolder] = React.useState(!!row.content);
    const [isOpen, setIsOpen] = React.useState((!!((_b = row.content) === null || _b === void 0 ? void 0 : _b.length) && false) || root);
    const [isEdit, setIsEdit] = React.useState(false);
    const [addNew, setAddNew] = React.useState(false);
    const { focusedNode } = useSandbox();
    const classNames = useClassNames();
    React.useEffect(() => {
        if ((props.addFile || props.addFolder) && (focusedNode === null || focusedNode === void 0 ? void 0 : focusedNode.path) === row.path) {
            setAddNew(true);
            setIsOpen(true);
        }
        else if (addNew) {
            setAddNew(false);
        }
    }, [props.addFile, props.addFolder]);
    const getIcon = () => {
        const folder = ['folder-open.svg', 'folder.svg'];
        const IconPath = (icon) => React.createElement("img", { className: "monaco-tree-icon", src: `https://cdn.jsdelivr.net/npm/material-icon-theme@3.7.1/icons/${icon}` });
        const fileIcon = getIconForFile(row.name);
        if (!isFolder)
            return IconPath(fileIcon);
        const folderIcon = isOpen ? getIconForOpenFolder(row.name) : getIconForFolder(row.name);
        return folder.includes(folderIcon) ? (isOpen ? React.createElement(DirectoryIconOpen, null) : React.createElement(DirectoryIconClosed, null)) : IconPath(folderIcon);
    };
    const handleClickFile = (data) => clickFile(data);
    const toggle = () => { setIsOpen(!isOpen); clickFile(row); };
    const onBlur = () => {
        setIsEdit(false);
        props.setAddFile(false);
        props.setAddFolder(false);
    };
    return (React.createElement("div", null,
        !hide &&
            React.createElement("div", { className: classNames('monaco-tree', [monacoTreeStyles, (isEdit || addNew) ? 'editing' : '']) },
                !root && React.createElement(React.Fragment, null,
                    React.createElement("div", { "data-active": activeFile === row.path, style: { paddingLeft: 12 * depth + "px" }, className: 'monaco-tree-row', onClick: toggle },
                        getIcon(),
                        isEdit ?
                            React.createElement(SingleInputForm, { isEdit: true, row: row, isFile: !isFolder, filename: row.name, currentPath: row.path, onBlur: setIsEdit }) :
                            React.createElement("div", { className: "monaco-tree-name" }, row.name)),
                    !row.readOnly && React.createElement("div", { className: "monaco-tree-actions" },
                        React.createElement(FileActions, { row: row, path: row.path, isFolder: isFolder, setIsEdit: setIsEdit }))),
                addNew && React.createElement("div", { className: 'monaco-tree-row', style: { paddingLeft: 12 * (depth + 1) + "px" } },
                    React.createElement("img", { className: "monaco-tree-icon", src: `https://cdn.jsdelivr.net/npm/material-icon-theme@3.7.1/icons/${props.addFile ? 'file' : 'folder-temp'}.svg` }),
                    React.createElement(SingleInputForm, { isEdit: false, isFile: props.addFile, filename: "", currentPath: row.path, row: row, onBlur: onBlur }))), (_c = row.content) === null || _c === void 0 ? void 0 :
        _c.map(x => {
            return React.createElement(MonacoFileTree, { activeFile: activeFile, key: x.name, row: x, depth: depth + 1, hide: !isOpen || hide, clickFile: handleClickFile, addFile: props.addFile, addFolder: props.addFolder, setAddFile: props.setAddFile, setAddFolder: props.setAddFolder });
        })));
};

function SandpackFileManager(_a) {
    var { className } = _a, props = __rest(_a, ["className"]);
    const { sandbox, setFocusedNode, tree } = useSandbox();
    const clickFile = (data) => {
        setFocusedNode(data.content ? data : getParentNode(tree, data.path));
        if (!data.content) {
            sandbox.openFile(data.path);
        }
    };
    return (React.createElement(React.Fragment, null, tree.map(x => {
        return React.createElement(MonacoFileTree, { root: true, key: x.name, row: x, depth: 0, hide: false, clickFile: clickFile, activeFile: sandbox.activeFile, addFile: props.addFile, addFolder: props.addFolder, setAddFile: props.setAddFile, setAddFolder: props.setAddFolder });
    })));
}
;

const reactSelectStyles = {
    control: (base) => (Object.assign(Object.assign({}, base), { minHeight: '28px', minWidth: '150px', cursor: 'text' })),
    dropdownIndicator: (provided) => (Object.assign(Object.assign({}, provided), { padding: '2px' })),
    menuPortal: (provided) => (Object.assign(Object.assign({}, provided), { zIndex: 9999 })),
};
const themes = [{ label: 'Light', value: 'light' }, { label: 'Dark', value: 'dark' }];
function Settings() {
    const { theme, setTheme } = useSandbox();
    const classNames = useClassNames();
    const [localTheme, setLocalTheme] = useState();
    useEffect(() => {
        const selectedTheme = themes.find(x => x.value === theme);
        setLocalTheme(selectedTheme);
    }, [theme]);
    return React__default.createElement("div", { className: classNames(`navigation-settings`, []) },
        React__default.createElement("div", { style: { display: 'flex', alignItems: 'center', justifyContent: 'space-between' } },
            React__default.createElement("h5", { style: { margin: 0 } }, "Themes"),
            React__default.createElement(Select, { className: "basic-single", classNamePrefix: "select", value: localTheme, isClearable: false, isSearchable: true, name: "color", options: themes, onChange: (e) => setTheme(e.value), styles: reactSelectStyles, menuPortalTarget: document.body })));
}

const collapseStyle = css({
    '.header-item': {
        minHeight: '$layout$headerHeight',
        paddingLeft: "12px",
        paddingRight: "12px",
        borderBottom: "1px solid $colors$surface2",
        borderTopCcolor: "$colors$surface2",
        borderRightCcolor: "$colors$surface2",
        borderLeftCcolor: "$colors$surface2",
        cursor: "pointer",
        display: 'flex',
        alignItems: 'center',
        '&__label': {
            display: 'flex',
            flex: 1,
            alignItems: 'center',
            '& svg': {
                marginRight: '5px',
                transition: 'transform 75ms ease 0s',
                opacity: 0.25,
            },
        },
        '&__actions': {
            display: 'flex',
            alignItems: 'center',
            '&> :not(:last-child)': {
                marginRight: '5px'
            }
        },
        userSelect: 'none'
    },
    '.container': {
        borderBottom: "1px solid $colors$surface2",
        borderTopColor: "$colors$surface2",
        borderRightColor: "$colors$surface2",
        borderLeftColor: "$colors$surface2",
        overflow: "auto",
        paddingTop: "16px",
        paddingBottom: "16px",
        opacity: 1,
        transition: "all 200ms ease 0s",
        paddingRight: "$space$3",
        paddingLeft: "$space$3",
    },
    '&.closed': {
        '.header-item': {
            '&__label': {
                '& svg': {
                    transform: 'rotate(-90deg)'
                }
            }
        },
        '.container': {
            borderBottom: "none $colors$surface2",
            overflow: "hidden",
            paddingTop: "0px",
            paddingBottom: "0px",
            opacity: 0,
        }
    }
});
const CollapsePanel = ({ title, container, action = null, panelOpen = true, alwaysShowAction = false }) => {
    const [open, setOpen] = useState(panelOpen);
    const classNames = useClassNames();
    return React__default.createElement("section", { className: classNames(`collapse ${open ? '' : 'closed'}`, [collapseStyle]) },
        React__default.createElement("div", { className: 'header-item', onClick: () => setOpen(!open) },
            React__default.createElement("div", { className: 'header-item__label' },
                React__default.createElement("svg", { width: "9", height: "6", viewBox: "0 0 9 6", xmlns: "http://www.w3.org/2000/svg" },
                    React__default.createElement("path", { d: "M4.50009 6L-5.24537e-07 1.26364e-06L9 4.76837e-07L4.50009 6Z", fill: "currentcolor" })),
                React__default.createElement("span", null, title)),
            (open || alwaysShowAction) && React__default.createElement("div", { className: 'header-item__actions' }, action)),
        React__default.createElement("div", { className: 'container' }, open ? container : ''));
};
function SandboxExplorer() {
    const [addFile, setAddFile] = useState(false);
    const [addFolder, setAddFolder] = useState(false);
    return (React__default.createElement(SandpackStack, { style: { height: '100%', overflow: 'auto' } },
        React__default.createElement(CollapsePanel, { panelOpen: false, title: 'Settings', container: React__default.createElement(Settings, null), alwaysShowAction: true }),
        React__default.createElement(CollapsePanel, { title: 'Files', container: React__default.createElement(SandpackFileManager, { addFile: addFile, addFolder: addFolder, setAddFile: setAddFile, setAddFolder: setAddFolder }), action: React__default.createElement(FileManagerAction, { setAddFile: setAddFile, setAddFolder: setAddFolder }) }),
        React__default.createElement(CollapsePanel, { panelOpen: false, title: 'Dependencies', container: React__default.createElement(DependencyManager, null) })));
}

function SandboxPreview() {
    const classNames = useClassNames();
    const { sandbox, props } = useSandbox();
    const [consoleWidth, setConsoleWidth] = useState('40px');
    return (React__default.createElement(Split, { lineBar: true, mode: 'vertical', style: { width: '35%', zIndex: 1 } },
        React__default.createElement(SandpackPreview, { style: { flex: 1, minHeight: 40 }, showNavigator: true, showOpenInCodeSandbox: false }),
        React__default.createElement("div", { style: { minHeight: 40, height: consoleWidth }, className: classNames("console-container", [consoleContainerStyle]) },
            React__default.createElement("div", { className: 'console-tabs' },
                React__default.createElement("div", { className: 'console-tabs__tabs' },
                    React__default.createElement("div", { className: 'console-tabs__tabs-label' }, " Console ")),
                React__default.createElement("div", { className: 'console-tabs__actions' },
                    props.showRunBtn && React__default.createElement("button", { onClick: () => sandbox.runCode(), className: classNames("action-buttons", [actionButtons, runButton, 'code-run']) }, "Run"),
                    props.showSubmitBtn && React__default.createElement("button", { onClick: () => sandbox.submitCode(), className: classNames("action-buttons", [actionButtons, submitButton, 'code-submit']) }, "Submit"))),
            React__default.createElement("div", { className: 'console-view' },
                React__default.createElement(SandpackConsole, { resetOnPreviewRestart: true })))));
}

const styles = css({
    height: '$layout$headerHeight',
    borderBottom: "1px solid $colors$surface2",
    background: "$colors$surface1",
    padding: '0 20px',
    justifyContent: 'space-between',
    alignItems: 'center',
    display: 'flex',
    button: {
        display: "flex",
        alignItems: "center",
        borderRadius: "4px",
        borderWidth: "0",
        background: "rgb(17, 109, 227)",
        color: "rgb(255, 255, 255)",
        cursor: "pointer",
        border: "1px solid transparent",
        fontSize: "12px",
        lineHeight: "15px",
        padding: "5px 8px",
    },
    '.toolbar-collapse button': {
        padding: 5
    },
    '.toolbar-fullscreen button': {
        gap: "6px",
        boxSizing: "border-box",
        background: "rgb(17, 109, 227)",
        whiteSpace: "nowrap",
        fontWeight: 500
    },
    '.env-name': {
        display: 'flex',
        flexDirection: 'row',
        gap: 5,
        img: {
            width: '20px'
        },
        span: {
            lineHeight: '18px',
            fontSize: "$font$size",
            color: "$syntax$color$plain",
        }
    }
});
const Sandbox = () => {
    var _a, _b;
    const { sandbox, theme, props } = useSandbox();
    const classNames = useClassNames();
    const [fullscreen, setFullscreen] = useState(false);
    const [expWidth, setExpWidth] = useState(250);
    useEffect(() => {
        props.toggleFullscreen(fullscreen);
    }, [fullscreen]);
    const toggleFullscreen = (event, value) => {
        event === null || event === void 0 ? void 0 : event.stopPropagation();
        setFullscreen(value);
    };
    const toggleExplorer = (event) => {
        event === null || event === void 0 ? void 0 : event.stopPropagation();
        setExpWidth(prev => prev === 0 ? 250 : 0);
    };
    return (React__default.createElement(SandpackProvider, { files: sandbox.files, theme: theme, options: { recompileDelay: 1000 }, customSetup: {}, style: { height: '100%', width: '100%', display: 'flex', flexDirection: 'column' } },
        React__default.createElement("div", { className: classNames('sadbox-toolbar', [styles]) },
            React__default.createElement("div", { className: "toolbar-collapse" },
                React__default.createElement("button", { type: "button", onClick: toggleExplorer },
                    React__default.createElement("svg", { height: "16", viewBox: "0 0 32 32", fill: "white", xmlns: "http://www.w3.org/2000/svg", xmlnsXlink: "http://www.w3.org/1999/xlink" },
                        React__default.createElement("path", { d: "M4,10h24c1.104,0,2-0.896,2-2s-0.896-2-2-2H4C2.896,6,2,6.896,2,8S2.896,10,4,10z M28,14H4c-1.104,0-2,0.896-2,2  s0.896,2,2,2h24c1.104,0,2-0.896,2-2S29.104,14,28,14z M28,22H4c-1.104,0-2,0.896-2,2s0.896,2,2,2h24c1.104,0,2-0.896,2-2  S29.104,22,28,22z" })))),
            React__default.createElement("div", { className: 'env-name' },
                React__default.createElement("img", { src: (_a = SandboxTemplates[props.environment]) === null || _a === void 0 ? void 0 : _a.icon }),
                React__default.createElement("span", null, (_b = SandboxTemplates[props.environment]) === null || _b === void 0 ? void 0 : _b.dn)),
            React__default.createElement("div", { className: "toolbar-fullscreen" },
                React__default.createElement("button", { type: "button", onClick: (e) => toggleFullscreen(e, !fullscreen) },
                    fullscreen ? React__default.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "-2 -2 24 24", width: "14" },
                        React__default.createElement("path", { fill: "currentColor", d: "M13 8h6c.6 0 1-.4 1-1s-.4-1-1-1h-3.6l4.3-4.3c.4-.4.4-1 0-1.4s-1-.4-1.4 0L14 4.6V1c0-.6-.4-1-1-1s-1 .4-1 1v6c0 .6.4 1 1 1zM7 0c-.6 0-1 .4-1 1v3.6L1.7.3C1.3-.1.7-.1.3.3s-.4 1 0 1.4L4.6 6H1c-.6 0-1 .4-1 1s.4 1 1 1h6c.6 0 1-.4 1-1V1c0-.6-.4-1-1-1zM20 13c0-.6-.4-1-1-1h-6c-.6 0-1 .4-1 1v6c0 .6.4 1 1 1s1-.4 1-1v-3.6l4.3 4.3c.2.2.5.3.7.3s.5-.1.7-.3c.4-.4.4-1 0-1.4L15.4 14H19c.6 0 1-.4 1-1zM7 12H1c-.6 0-1 .4-1 1s.4 1 1 1h3.6L.3 18.3c-.4.4-.4 1 0 1.4.2.2.4.3.7.3s.5-.1.7-.3L6 15.4V19c0 .6.4 1 1 1s1-.4 1-1v-6c0-.6-.4-1-1-1z" })) :
                        React__default.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "-2 -2 24 24", width: "13", fill: "currentColor" },
                            React__default.createElement("path", { d: "M19 0a1 1 0 0 1 1 1v6a1 1 0 0 1-2 0V3.414L11.414 10 18 16.586V13a1 1 0 0 1 2 0v6a1 1 0 0 1-1 1h-6a1 1 0 0 1 0-2h3.586L10 11.414 3.414 18H7a1 1 0 0 1 0 2H1a1 1 0 0 1-1-1v-6a1 1 0 0 1 2 0v3.586L8.586 10 2 3.414V7a1 1 0 1 1-2 0V1a1 1 0 0 1 1-1h6a1 1 0 1 1 0 2H3.414L10 8.586 16.586 2H13a1 1 0 0 1 0-2h6z" })),
                    "Toggle Fullscreen"))),
        React__default.createElement(Split, { lineBar: true, style: { width: '100%' } },
            React__default.createElement(Split, { lineBar: true, style: { flex: 1, width: '65%' }, visiable: expWidth !== 0 },
                React__default.createElement("div", { style: { width: expWidth, overflow: 'hidden', maxWidth: 350 } },
                    React__default.createElement("div", { style: { minWidth: 250 } },
                        "  ",
                        React__default.createElement(SandboxExplorer, null))),
                React__default.createElement("div", { style: { flex: 1, overflow: 'hidden' } },
                    " ",
                    React__default.createElement(SandboxEditor, null))),
            React__default.createElement(SandboxPreview, null))));
};
function SandpackWrapper(props) {
    return React__default.createElement(SandboxProvider, Object.assign({}, props),
        " ",
        React__default.createElement(Sandbox, null),
        " ");
}

class ReactDirective {
    constructor(host) {
        this.host = host;
        this.root = createRoot(this.host.nativeElement);
    }
    ngOnChanges() {
        return __awaiter(this, void 0, void 0, function* () {
            this.root.render(createElement(this.component, this.props));
        });
    }
    ngOnDestroy() {
        var _a;
        (_a = this.root) === null || _a === void 0 ? void 0 : _a.unmount();
    }
}
ReactDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: ReactDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
ReactDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.17", type: ReactDirective, selector: "[cjReact]", inputs: { component: "component", props: "props" }, usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: ReactDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[cjReact]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { component: [{
                type: Input
            }], props: [{
                type: Input
            }] } });

class SandpackComponent {
    constructor(cd, dialog) {
        this.cd = cd;
        this.dialog = dialog;
        this.showRunBtn = true;
        this.showSubmitBtn = true;
        this.onFileChanges = new EventEmitter();
        this.onSandboxMount = new EventEmitter();
        this.afterRunCode = new EventEmitter();
        this.afterSubmitCode = new EventEmitter();
        this.component = SandpackWrapper;
        this.isFullscreen = false;
    }
    ngOnInit() {
        if (this.sandboxId) {
            this.setup();
        }
    }
    ngOnChanges(changes) {
        if (changes.sandboxId && !changes.sandboxId.firstChange) {
            this.props = null;
            if (this.sandboxId) {
                this.setup();
            }
        }
        else if (this.sandboxId && !this.props && ((changes.files && !changes.files.firstChange) || (changes.templateUrl && !changes.templateUrl.firstChange))) {
            this.setup();
        }
    }
    setup() {
        if (this === null || this === void 0 ? void 0 : this.files) {
            this.setupSandbox();
        }
        else if (this === null || this === void 0 ? void 0 : this.templateUrl) {
            this.setupFiles();
        }
    }
    setupSandbox() {
        var _a;
        (_a = this.filesSubs) === null || _a === void 0 ? void 0 : _a.unsubscribe();
        this.filesSubs = timer(500).subscribe(res => {
            this.props = {
                files: this.files,
                sandboxId: this.sandboxId || v4(),
                showRunBtn: this.showRunBtn,
                showSubmitBtn: this.showSubmitBtn,
                onFileChanges: (files) => { this.files = files; setTimeout(() => this.onFileChanges.next(this.files), 500); },
                onRunCode: (files) => this.executeCode(files, 'RUN'),
                onSubmitCode: (files) => this.executeCode(files, 'SUBMIT'),
                onSandboxMount: (context) => this.onSandboxMount.emit(context),
                toggleFullscreen: (isFullscreen) => this.toggleFullscreen(isFullscreen),
                environment: this.environment
            };
        });
    }
    setupFiles() {
        var _a;
        (_a = this.filesSubs) === null || _a === void 0 ? void 0 : _a.unsubscribe();
        this.filesSubs = fetchFromUrl(this.templateUrl).subscribe(res => {
            this.files = this.cleanUpData(res);
            // this.files['/package.json'].readOnly = true;
            this.setupSandbox();
        });
    }
    cleanUpData(data) {
        data = pickBy(data, (value, key) => !isEmpty(value));
        data = mapKeys(data, (value, key) => key.startsWith('/') ? key : `/${key}`);
        return isEmpty(data) ? null : data;
    }
    executeCode(files, type) {
        this.openDialog({ type, files }).subscribe(res => type === 'RUN' ? this.afterRunCode.emit(res) : this.afterSubmitCode.emit(res));
    }
    ;
    ngOnDestroy() {
        var _a;
        (_a = this.filesSubs) === null || _a === void 0 ? void 0 : _a.unsubscribe();
    }
    openDialog(data) {
        return this.dialog.open(CodeSubmissionComponent, {
            panelClass: 'code-submission-panel',
            maxWidth: '950px',
            minWidth: '35vw',
            maxHeight: '80vh',
            minHeight: '230px',
            autoFocus: false,
            data: Object.assign(Object.assign({}, data), { user_type: this.user_type, portal: this.portal, test_type: this.test_type, test_uuid: this.test_uuid, question: this.question, language_id: this.language_id }),
            disableClose: true
        })
            .afterClosed().pipe(take(1));
    }
    toggleFullscreen(isFullscreen) {
        this.isFullscreen = isFullscreen;
        this.cd.markForCheck();
    }
}
SandpackComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: SandpackComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i2.MatDialog }], target: i0.ɵɵFactoryTarget.Component });
SandpackComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: SandpackComponent, selector: "cj-sandpack", inputs: { files: "files", templateUrl: "templateUrl", sandboxId: "sandboxId", portal: "portal", user_type: "user_type", test_uuid: "test_uuid", test_type: "test_type", language_id: "language_id", question: "question", showRunBtn: "showRunBtn", showSubmitBtn: "showSubmitBtn", environment: "environment" }, outputs: { onFileChanges: "onFileChanges", onSandboxMount: "onSandboxMount", afterRunCode: "afterRunCode", afterSubmitCode: "afterSubmitCode" }, usesOnChanges: true, ngImport: i0, template: "<div class=\"sandpack-main-ide\" [ngClass]=\"{'fullscreen': isFullscreen}\">\n    <div *ngIf=\"props?.files\" style=\"height: 100%;width: 100%;\" cjReact [component]=\"component\" [props]=\"props\"></div>\n    <div *ngIf=\"!props?.files\" style=\"height: 100%;display: flex;align-items: center;justify-content: center;\">\n        <mat-spinner [diameter]=\"30\"></mat-spinner>\n    </div>\n</div>", styles: [".sandpack-main-ide{border:1px solid #d1d1d1!important;border-radius:4px;height:100%;width:100%}.sandpack-main-ide.fullscreen{position:fixed;top:0;left:0;z-index:99;right:0}\n"], components: [{ type: i2$1.MatSpinner, selector: "mat-spinner", inputs: ["color"] }], directives: [{ type: i7.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i7.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: ReactDirective, selector: "[cjReact]", inputs: ["component", "props"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: SandpackComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'cj-sandpack',
                    templateUrl: './sandpack.component.html',
                    styleUrls: ['./sandpack.component.scss'],
                }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }, { type: i2.MatDialog }]; }, propDecorators: { files: [{
                type: Input
            }], templateUrl: [{
                type: Input
            }], sandboxId: [{
                type: Input
            }], portal: [{
                type: Input
            }], user_type: [{
                type: Input
            }], test_uuid: [{
                type: Input
            }], test_type: [{
                type: Input
            }], language_id: [{
                type: Input
            }], question: [{
                type: Input
            }], showRunBtn: [{
                type: Input
            }], showSubmitBtn: [{
                type: Input
            }], environment: [{
                type: Input
            }], onFileChanges: [{
                type: Output
            }], onSandboxMount: [{
                type: Output
            }], afterRunCode: [{
                type: Output
            }], afterSubmitCode: [{
                type: Output
            }] } });

class DirectivesModule {
}
DirectivesModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: DirectivesModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
DirectivesModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: DirectivesModule, declarations: [ReactDirective], imports: [CommonModule], exports: [ReactDirective] });
DirectivesModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: DirectivesModule, imports: [[
            CommonModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: DirectivesModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        ReactDirective
                    ],
                    imports: [
                        CommonModule
                    ],
                    exports: [ReactDirective]
                }]
        }] });

class PopupsModule {
}
PopupsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: PopupsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
PopupsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: PopupsModule, declarations: [CodeSubmissionComponent], imports: [CommonModule,
        MatProgressBarModule,
        MatIconModule,
        MatButtonModule,
        MatTableModule,
        MatTooltipModule] });
PopupsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: PopupsModule, imports: [[
            CommonModule,
            MatProgressBarModule,
            MatIconModule,
            MatButtonModule,
            MatTableModule,
            MatTooltipModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: PopupsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        CodeSubmissionComponent
                    ],
                    imports: [
                        CommonModule,
                        MatProgressBarModule,
                        MatIconModule,
                        MatButtonModule,
                        MatTableModule,
                        MatTooltipModule
                    ]
                }]
        }] });

class SandpackModule {
}
SandpackModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: SandpackModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SandpackModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: SandpackModule, declarations: [SandpackComponent], imports: [CommonModule,
        DirectivesModule,
        PopupsModule,
        MatProgressSpinnerModule,
        MatDialogModule], exports: [SandpackComponent] });
SandpackModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: SandpackModule, imports: [[
            CommonModule,
            DirectivesModule,
            PopupsModule,
            MatProgressSpinnerModule,
            MatDialogModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: SandpackModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        SandpackComponent
                    ],
                    imports: [
                        CommonModule,
                        DirectivesModule,
                        PopupsModule,
                        MatProgressSpinnerModule,
                        MatDialogModule
                    ],
                    exports: [SandpackComponent]
                }]
        }] });

class CodejudgeModule {
    constructor() {
    }
    static forRoot(configuration) {
        configuration = this.transformConfigurations(configuration);
        AWS.initialize(configuration);
        return {
            ngModule: CodejudgeModule,
            providers: [{ provide: 'environment', useValue: configuration }]
        };
    }
    static transformConfigurations(configuration) {
        var _a, _b, _c;
        return Object.assign(Object.assign({}, configuration), { coreApiUrl: (_a = configuration.coreApiUrl) !== null && _a !== void 0 ? _a : configuration.host0, recruitApiUrl: (_b = configuration.apiUrl) !== null && _b !== void 0 ? _b : configuration.host2, developerApiUrl: (_c = configuration.developerApiUrl) !== null && _c !== void 0 ? _c : configuration.host1 });
    }
}
CodejudgeModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: CodejudgeModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CodejudgeModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: CodejudgeModule, imports: [HttpClientModule] });
CodejudgeModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: CodejudgeModule, imports: [[
            HttpClientModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: CodejudgeModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [
                        HttpClientModule
                    ],
                }]
        }], ctorParameters: function () { return []; } });

/*
 * Public API Surface of Codejudge
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AWS, CodejudgeModule, Constants, DirectivesModule, PORTAL, ReactDirective, SandboxTemplates, SandpackComponent, SandpackModule, USER_TYPE, fetchFromUrl, pollWhile, resolvablePromise, runInZone };
//# sourceMappingURL=opencoders-codejudge.js.map
